/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

 ( function( $ ) {

 	const power_news_pro_section_lists = ['trending_news_section', 'breaking_news_section', 'featured_posts_section', 'about_us_section', 'latest_products_section', 'popular_products_section', 'products_collection_section', 'courses_section', 'gallery_section', 'team_section', 'events_section', 'career_section', 'testimonial_section', 'media_posts_section', 'latest_posts_section', 'popular_posts_section', 'most_viewed_section', 'posts_slider_section', 'multiple_posts_section', 'media_posts_section', 'promotion_section', 'recent_products_section', 'featured_products_section', 'subscribe_us_section', 'our_services_section', 'related_posts_section'];
 	power_news_pro_section_lists.forEach( power_news_pro_homepage_scroll_preview );

 	function power_news_pro_homepage_scroll_preview(item, index) {
		// Collect information from customize-controls.js about which panels are opening.
		wp.customize.bind( 'preview-ready', function() {

		// Initially hide the theme option placeholders on load.
		$( '.panel-placeholder' ).hide();
		wp.customize.preview.bind( item, function( data ) {
		// Only on the front page.
		if ( ! $( 'body' ).hasClass( 'home' ) ) {
			return;
		}

		// When the section is expanded, show and scroll to the content placeholders, exposing the edit links.
		if ( true === data.expanded ) {
			$('html, body').animate({
				'scrollTop' : $('#power_news_pro_'+item).position().top
			});
		} 
	});

	});
	}

	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			console.log(to);
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a, .site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header title color.
	wp.customize( 'power_news_pro_theme_options[header_title_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header tagline color.
	wp.customize( 'power_news_pro_theme_options[header_tagline_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Color scheme.
	wp.customize( 'power_news_pro_theme_options[colorscheme]', function( value ) {
		value.bind( function( to ) {

			// Update color body class.
			$( 'body' )
			.removeClass( 'colors-legit colors-dark colors-custom' )
			.addClass( 'colors-' + to );
		});
	});

	// Custom color hue.
	wp.customize( 'power_news_pro_theme_options[colorscheme_hue]', function( value ) {
		value.bind( function( to ) {

			// Update custom color CSS
			var style = $( '#custom-theme-colors' ),
			color = style.data( 'color' ),
			css = style.html();
			css = css.split( color ).join( to );
			style.html( css )
			.data( 'color', to );
		} );
	} );

	// Topbar Menu Background Color
	wp.customize( 'power_news_pro_theme_options[secondary_menu_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation, #site-navigation' ).css( {
				'background-color': to
			} );
		} );
	} );

	// Topbar menu item color
	wp.customize( 'power_news_pro_theme_options[topbar_menu_item_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .main-navigation ul.nav-menu > li > a, #top-navigation .main-navigation ul.nav-menu > li.current-date' ).css( {
				'color': to
			} );

			$( '#top-navigation .social-icons a svg' ).css( {
				'fill': to
			} );
		} );
	} );

	// Topbar item hover color
	wp.customize( 'power_news_pro_theme_options[topbar_item_hover_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .main-navigation ul.nav-menu > li > a:hover, #top-navigation .main-navigation ul.nav-menu > li > a:focus' ).css( {
				'background-color': to
			} );
		} );
	} );

	// Blog info background image
	wp.customize( 'power_news_pro_theme_options[blog_info_bg_img]', function( value ) {
		value.bind( function( to ) {
			if ( to ) {
				$('.site-branding-container').css( 'background-image', 'url(' + to + ')' );
				$('.site-branding-container').css( 'background-size', 'cover' );
				$('.site-branding-container').css( 'background-repeat', 'no-repeat' );
				$('.site-branding-container').css( 'background-position', 'center' );
			}else {
				$('.site-branding-container').css( 'background-image', 'none' );
			}
		} );
	} );
	// Topbar menu item color
	/*wp.customize( 'power_news_pro_theme_options[topbar_menu_item_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation .main-navigation ul.nav-menu > li > a, #top-navigation .main-navigation ul.nav-menu > li.current-date' ).css( {
				'color': to
			} );

			$( '#top-navigation .social-icons a svg' ).css( {
				'fill': to
			} );
		} );
	} );*/

	// Blog Info Section Background Color
	wp.customize( 'power_news_pro_theme_options[blog_info_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '.site-branding-container' ).css( {
				'background-color': to
			} );
		} );
	} );


	// Primary menu hover color change
	wp.customize( 'power_news_pro_theme_options[primary_menu_hover_color]', function( value ) {
		value.bind( function( to ) {
			$( '#masthead .main-navigation ul.nav-menu li.current-menu-item > a, #masthead .main-navigation ul#primary-menu > li > a:hover, #masthead .main-navigation ul.#primary-menu > li > a:focus, .main-navigation ul.nav-menu li:hover > a, .main-navigation ul.#primary-menu li.focus > a' ).css( {
				'background-color': to
			} );
		} );
	} );


	// Primary menu item color
	wp.customize( 'power_news_pro_theme_options[primary_menu_item_color]', function( value ) {
		value.bind( function( to ) {
			$('#ph-styles').remove();
			var $style = $('<style>').attr('id', 'ph-styles');
			$style.text(
				'.main-navigation form.search-form ::placeholder { ' +
				'color: ' + to +
				'}');
			$style.appendTo('head');
			$( '.main-navigation ul#primary-menu > li > a' ).css( {
				'color': to
			} );

			$( '#masthead .home-icon > a svg.icon-home' ).css( {
				'fill': to
			} );
		} );
	} );


	// footer background color
	wp.customize( 'power_news_pro_theme_options[footer_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '#colophon' ).css( {
				'background-color': to
			} );
		} );
	} );

	// footer widget title color
	wp.customize( 'power_news_pro_theme_options[footer_widget_title_color]', function( value ) {
		value.bind( function( to ) {
			$( '#colophon .widget-title' ).css( {
				'color': to
			} );
		} );
	} );

	// footer widget content color
	wp.customize( 'power_news_pro_theme_options[footer_widget_content_color]', function( value ) {
		value.bind( function( to ) {
			$( '#colophon .cat-links a, #colophon ul li .entry-header .entry-title a, #colophon .site-info span, #colophon .site-info a' ).css( {
				'color': to
			} );
		} );
	} );


	// footer item hover color
	wp.customize( 'power_news_pro_theme_options[footer_widget_hover_color]', function( value ) {
		value.bind( function( to ) {
			$( '#colophon ul li a:hover, #colophon ul li a:focus, #colophon .site-info a:hover' ).css( {
				'color': to
			} );
		} );
	} );

	// Banner settings
	wp.customize( 'power_news_pro_theme_options[banner_section_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '.blog .header-wrapper, .archive .header-wrapper, .single .header-wrapper' ).css( {
				'background-color': to
			} );
		} );
	} );

	// Banner text align
	wp.customize( 'power_news_pro_theme_options[banner_text_align]', function( value ) {
		value.bind( function( to ) {
			$( '.blog .header-wrapper, .archive .header-wrapper, .single .header-wrapper' ).css( {
				'text-align': to
			} );
		} );
	} );

	// Banner title color
	wp.customize( 'power_news_pro_theme_options[banner_title_color]', function( value ) {
		value.bind( function( to ) {
			$( '.blog .header-wrapper .page-header h2.page-title, .archive .header-wrapper .page-header h2.page-title, .single .header-wrapper .page-header h2.page-title' ).css( {
				'color': to
			} );
		} );
	} );


	// Banner anchor text color color
	wp.customize( 'power_news_pro_theme_options[banner_anchor_text_color]', function( value ) {
		value.bind( function( to ) {
			$( '.trail-items li a' ).css( {
				'color': to
			} );
		} );
	} );

	// Banner text color color
	wp.customize( 'power_news_pro_theme_options[banner_text_color]', function( value ) {
		value.bind( function( to ) {
			$( '.trail-items li' ).css( {
				'color': to
			} );
		} );
	} );

	// Banner wrapper padding top
	wp.customize( 'power_news_pro_theme_options[banner_wrapper_padding_top]', function( value ) {
		value.bind( function( to ) {
			$( '.blog .header-wrapper, .archive .header-wrapper, .single .header-wrapper' ).css( {
				'padding-top': to + 'px'
			} );
		} );
	} );


	// Banner wrapper padding top
	wp.customize( 'power_news_pro_theme_options[banner_wrapper_padding_buttom]', function( value ) {
		value.bind( function( to ) {
			$( '.blog .header-wrapper, .archive .header-wrapper, .single .header-wrapper' ).css( {
				'padding-bottom': to + 'px'
			} );
		} );
	} );


	} )( jQuery );
