/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	const power_news_pro_section_lists = ['trending_news_section', 'breaking_news_section', 'featured_posts_section', 'about_us_section', 'latest_products_section', 'popular_products_section', 'products_collection_section', 'courses_section', 'gallery_section', 'team_section', 'events_section', 'career_section', 'testimonial_section', 'media_posts_section', 'latest_posts_section', 'popular_posts_section', 'most_viewed_section', 'posts_slider_section', 'multiple_posts_section', 'media_posts_section', 'promotion_section', 'recent_products_section', 'featured_products_section', 'subscribe_us_section', 'our_services_section', 'related_posts_section'];
	power_news_pro_section_lists.forEach( power_news_pro_homepage_scroll_preview );

	function power_news_pro_homepage_scroll_preview(item, index) {
		// Collect information from customize-controls.js about which panels are opening.
		wp.customize.bind( 'preview-ready', function() {

		// Initially hide the theme option placeholders on load.
		$( '.panel-placeholder' ).hide();
		wp.customize.preview.bind( item, function( data ) {
		// Only on the front page.
		if ( ! $( 'body' ).hasClass( 'home' ) ) {
			return;
		}

		// When the section is expanded, show and scroll to the content placeholders, exposing the edit links.
		if ( true === data.expanded ) {
			$('html, body').animate({
				'scrollTop' : $('#power_news_pro_'+item).position().top
			});
		} 
	});

	});
	}

	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			console.log(to);
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a, .site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header title color.
	wp.customize( 'power_news_pro_theme_options[header_title_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title a' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Header tagline color.
	wp.customize( 'power_news_pro_theme_options[header_tagline_color]', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	// Color scheme.
	wp.customize( 'power_news_pro_theme_options[colorscheme]', function( value ) {
		value.bind( function( to ) {

			// Update color body class.
			$( 'body' )
				.removeClass( 'colors-legit colors-dark colors-custom' )
				.addClass( 'colors-' + to );
		});
	});

	// Custom color hue.
	wp.customize( 'power_news_pro_theme_options[colorscheme_hue]', function( value ) {
		value.bind( function( to ) {

			// Update custom color CSS
			var style = $( '#custom-theme-colors' ),
			    color = style.data( 'color' ),
			    css = style.html();
			css = css.split( color ).join( to );
			style.html( css )
			     .data( 'color', to );
		} );
	} );

	// Header tagline color.
	wp.customize( 'power_news_pro_theme_options[secondary_menu_bg_color]', function( value ) {
		value.bind( function( to ) {
			$( '#top-navigation' ).css( {
				'background-color': to
			} );
		} );
	} );


} )( jQuery );
