<?php
/**
 * Power News Pro: Color Patterns
 *
 * @package WordPress
 * @subpackage Power News Pro
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function power_news_pro_custom_colors_css() {
  	$options= power_news_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	/*--------------------------------------------------------------
## Red Color
--------------------------------------------------------------*/
.backtotop,
.slick-prev, 
.slick-next,
.pagination .page-numbers.current, 
.pagination .page-numbers:hover, 
.pagination .page-numbers:focus,
span.min-read,
.reply a,
input[type="submit"],
.btn,
#power_news_pro_career_section .slick-dots li.slick-active button,
.separator,
#power_news_pro_testimonial_section .slick-dots li.slick-active button,
.second-design .post-categories a, 
.second-design #secondary .post-categories a, 
.second-design #secondary-sidebar .post-categories a, 
.second-design #colophon .cat-links a,
.jetpack_subscription_widget input[type="submit"],
.woocommerce #respond input#submit, 
.woocommerce a.button, 
.woocommerce button.button, 
.woocommerce input.button,
.service-item-wrapper .icon-container a {
    background-color: ' . esc_attr( $color_value ) . ';
}


button:hover,
input[type="button"]:hover,
input[type="reset"]:hover,
button:focus,
input[type="button"]:focus,
input[type="reset"]:focus,
button:active,
input[type="button"]:active,
input[type="reset"]:active,
.site-title a:hover,
.site-title a:focus,
a:hover, 
a:focus, 
.site-description,
.main-navigation a:hover, 
.main-navigation a:focus, 
.main-navigation ul.nav-menu > li > a:hover, 
.main-navigation ul.nav-menu > li > a:focus,
.navigation.post-navigation a:hover,
.navigation.posts-navigation a:hover,
.navigation.post-navigation a:focus,
.navigation.posts-navigation a:focus,
#secondary .cat-links a,
#secondary a:hover,
#secondary a:focus,
.comment-meta .url:hover,
.comment-meta .url:focus,
.comment-metadata a:hover time,
.comment-metadata a:focus time,
.single-wrapper .entry-meta span a:hover, 
.single-wrapper .entry-meta span a:focus,
.single-wrapper .cat-links a,
.single-wrapper .entry-meta span.byline a.fn:hover,
.single-wrapper .entry-meta span.byline a.fn:focus,
.single-wrapper .entry-meta > span a:hover,
.single-wrapper .entry-meta > span a:focus,
.section-title a:hover, 
.section-title a:focus,
.post-wrapper .entry-meta ul.post-categories li a:hover, 
.post-wrapper .entry-meta ul.post-categories li a:focus,
.entry-title a:hover,
.entry-title a:focus,
.widget_posts_filter .widget-title span.active,
.post-categories a, 
.posted-on a,
#colophon .cat-links a,
.byline a:hover, 
.byline a:focus,
.more-link a:hover, 
.more-link a:focus,
.posted-on a:hover, 
.posted-on a:focus,
#power_news_pro_testimonial_section .position,
.site-info a,
.product_meta a:hover, 
.product_meta a:focus, 
.woocommerce div.product p.price,
.woocommerce div.product span.price,
.woocommerce ul.products li.product .price,
.service-item-wrapper .entry-title a:hover, 
.service-item-wrapper .entry-title a:focus {
    color: ' . esc_attr( $color_value ) . ';
}   


.slick-prev:hover, 
.slick-next:hover, 
.slick-prev:focus, 
.slick-next:focus,
button, 
input[type="button"], 
input[type="reset"], 
input[type="submit"],
.section-title,
.pagination .page-numbers.current, 
.pagination .page-numbers:hover, 
.pagination .page-numbers:focus,
.slick-dots li button,
.woocommerce #respond input#submit, 
.woocommerce a.button, 
.woocommerce button.button, 
.woocommerce input.button {
    border-color: ' . esc_attr( $color_value ) . ';
}

.main-navigation ul#primary-menu li:hover > svg,
.main-navigation ul#primary-menu li:focus > svg,
.main-navigation li.menu-item-has-children:hover > a > svg,
.main-navigation li.menu-item-has-children > a:hover > svg,
.main-navigation li.menu-item-has-children > a:focus > svg,
.main-navigation li.search-menu a:hover svg,
.main-navigation li.search-menu a.search-active:hover svg,
.main-navigation ul#primary-menu li.search-menu:hover > a.search-active svg,
.navigation.post-navigation a:hover svg,
.navigation.posts-navigation a:hover svg,
.navigation.post-navigation a:focus svg,
.navigation.posts-navigation a:focus svg,
.loader-container svg,
.more-link a:hover svg, 
.more-link a:focus svg  {
    fill: ' . esc_attr( $color_value ) . ';
}

/*--------------------------------------------------------------
## Yellow Color
--------------------------------------------------------------*/
@media screen and (min-width: 1022px) {
	#power_news_pro_breaking_news_section .news-title,
    #masthead .main-navigation ul.nav-menu li.current-menu-item > a, 
    #masthead .main-navigation ul.nav-menu > li > a:hover, 
    #masthead .main-navigation ul.nav-menu > li > a:focus, 
    .main-navigation ul.nav-menu li:hover > a, 
    .main-navigation ul.nav-menu li.focus > a,
    .main-navigation ul.sub-menu li:hover > a,
    .main-navigation ul.sub-menu li:focus > a {
        background-color: ' . esc_attr( $color_value ) . ';
    }
}

/*--------------------------------------------------------------
## Preloader
--------------------------------------------------------------*/

@keyframes preloader {
    0% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
    25% {height:30px;transform:translateY(15px);background: ' . esc_attr( $color_value ) . ';}
    50% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
    100% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
}



	';

	/**
	 * Filters Power News Pro custom colors CSS.
	 *
	 * @since Power News Pro 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'power_news_pro_custom_colors_css', $css );
}
