<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

if ( ! function_exists( 'power_news_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Power News Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function power_news_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'power_news_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'power_news_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Power News Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function power_news_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'power_news_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'power_news_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Power News Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function power_news_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'power_news_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[topbar_section_enable]' )->value() );
}

/****************************Breaking News****************************************** */

/**
 * Check if Breaking News section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_breaking_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[breaking_news_section_enable]' )->value() );
}

/**
 * Check if Breaking News section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_breaking_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[breaking_news_content_type]' )->value();
	return power_news_pro_is_breaking_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if Breaking News section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_breaking_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[breaking_news_content_type]' )->value();
	return power_news_pro_is_breaking_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if Breaking News section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_breaking_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[breaking_news_content_type]' )->value();
	return power_news_pro_is_breaking_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if weather section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_weather_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[weather_section_enable]' )->value() );
}

/*==================Featured Posts===============*/

/**
 * Check if featured_post section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_featured_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[featured_posts_section_enable]' )->value() );
}

/**
 * Check if featured_post section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_featured_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[featured_posts_content_type]' )->value();
	return power_news_pro_is_featured_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_post section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_featured_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[featured_posts_content_type]' )->value();
	return power_news_pro_is_featured_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_post section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_featured_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[featured_posts_content_type]' )->value();
	return power_news_pro_is_featured_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*==================Latest Posts===============*/

/**
 * Check if latest_post section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_latest_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[latest_post_section_enable]' )->value() );
}

/**
 * Check if latest_post section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_latest_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[latest_post_content_type]' )->value();
	return power_news_pro_is_latest_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_post section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_latest_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[latest_post_content_type]' )->value();
	return power_news_pro_is_latest_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_post section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_latest_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[latest_post_content_type]' )->value();
	return power_news_pro_is_latest_post_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Popular Posts===============*/

/**
 * Check if latest_post section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[popular_post_section_enable]' )->value() );
}

/**
 * Check if popular_post section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_popular_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[popular_post_content_type]' )->value();
	return power_news_pro_is_popular_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_post section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_popular_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[popular_post_content_type]' )->value();
	return power_news_pro_is_popular_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular_post section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_popular_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[popular_post_content_type]' )->value();
	return power_news_pro_is_popular_post_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Most Viewed Posts===============*/

/**
 * Check if latest_post section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_most_viewed_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[most_viewed_section_enable]' )->value() );
}

/**
 * Check if most_viewed section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_most_viewed_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[most_viewed_content_type]' )->value();
	return power_news_pro_is_most_viewed_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_viewed section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_most_viewed_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[most_viewed_content_type]' )->value();
	return power_news_pro_is_most_viewed_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if most_viewed section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_most_viewed_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[most_viewed_content_type]' )->value();
	return power_news_pro_is_most_viewed_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================News Posts Slider===============*/

/**
 * Check if latest_post section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_news_posts_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[news_posts_slider_section_enable]' )->value() );
}

/**
 * Check if news_posts_slider section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_news_posts_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[news_posts_slider_content_type]' )->value();
	return power_news_pro_is_news_posts_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if news_posts_slider section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_news_posts_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[news_posts_slider_content_type]' )->value();
	return power_news_pro_is_news_posts_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if news_posts_slider section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_news_posts_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[news_posts_slider_content_type]' )->value();
	return power_news_pro_is_news_posts_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Multi Posts Section===============*/

/**
 * Check if multi_post section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_multi_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[multi_post_section_enable]' )->value() );
}

/**
 * Check if multi_post section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_multi_post_col1_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[multi_post_col1_content_type]' )->value();
	return power_news_pro_is_multi_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if multi_post section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_multi_post_col1_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[multi_post_col1_content_type]' )->value();
	return power_news_pro_is_multi_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if multi_post section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_multi_post_col1_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[multi_post_col1_content_type]' )->value();
	return power_news_pro_is_multi_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if multi_post section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_multi_post_col2_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[multi_post_col2_content_type]' )->value();
	return power_news_pro_is_multi_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if multi_post section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_multi_post_col2_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[multi_post_col2_content_type]' )->value();
	return power_news_pro_is_multi_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if multi_post section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_multi_post_col2_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[multi_post_col2_content_type]' )->value();
	return power_news_pro_is_multi_post_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Media Posts Section===============*/

/**
 * Check if featured section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_media_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[media_post_section_enable]' )->value() );
}

/**
 * Check if video section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_video_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[media_video_post_content_type]' )->value();
	return power_news_pro_is_media_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if video section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_video_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[media_video_post_content_type]' )->value();
	return power_news_pro_is_media_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if media section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_video_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[media_video_post_content_type]' )->value();
	return power_news_pro_is_media_post_section_enable( $control ) && ( 'category' == $content_type );
}



/**
 * Check if slider section content type is custom.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_media_post_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[media_video_post_content_type]' )->value();
	return power_news_pro_is_media_post_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_media_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[media_post_content_type]' )->value();
	return power_news_pro_is_media_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if media section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_media_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[media_post_content_type]' )->value();
	return power_news_pro_is_media_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if media section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_media_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[media_post_content_type]' )->value();
	return power_news_pro_is_media_post_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Related Posts===============*/

/**
 * Check if related posts section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_related_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[related_posts_section_enable]' )->value() );
}

/**
 * Check if related_posts section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_related_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[related_posts_content_type]' )->value();
	return power_news_pro_is_related_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if related_posts section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_related_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[related_posts_content_type]' )->value();
	return power_news_pro_is_related_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if related_posts section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_related_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[related_posts_content_type]' )->value();
	return power_news_pro_is_related_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/*==================Promotion===============*/

/**
 * Check if promotion section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_promotion_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[promotion_section_enable]' )->value() );
}

/**
 * Check if promotion section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_promotion_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[promotion_content_type]' )->value();
	return power_news_pro_is_promotion_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if promotion section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_promotion_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[promotion_content_type]' )->value();
	return power_news_pro_is_promotion_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if promotion section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_not_promotion_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[promotion_content_type]' )->value();
	return power_news_pro_is_promotion_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if promotion section content type is custom.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_promotion_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[promotion_content_type]' )->value();
	return power_news_pro_is_promotion_section_enable( $control ) && ( 'custom' == $content_type );
}

/*==================Suscribe Us===============*/

/**
 * Check if subscription section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_subscribe_us_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[subscribe_us_section_enable]' )->value() );
}

/*==================About Us===============*/

/**
 * Check if about section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_about_us_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[about_us_section_enable]' )->value() );
}


/**
 * Check if about section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_about_us_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[about_us_content_type]' )->value();
	return power_news_pro_is_about_us_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_about_us_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[about_us_content_type]' )->value();
	return power_news_pro_is_about_us_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_about_us_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[about_us_content_type]' )->value();
	return power_news_pro_is_about_us_section_enable( $control ) && ( 'custom' == $content_type );
}

/*==================Courses===============*/

/**
 * Check if course section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_courses_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[courses_section_enable]' )->value() );
}

/**
 * Check if course section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_courses_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[courses_content_type]' )->value();
	return power_news_pro_is_courses_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_courses_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[courses_content_type]' )->value();
	return power_news_pro_is_courses_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_courses_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[courses_content_type]' )->value();
	return power_news_pro_is_courses_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if course separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_courses_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'power_news_pro_theme_options[courses_content_type]' )->value();
    return power_news_pro_is_courses_section_enable( $control ) && !( 'category' == $content_type );
}

/*==================Gallery===============*/

/**
 * Check if gallery section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[gallery_content_type]' )->value();
	return power_news_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[gallery_content_type]' )->value();
	return power_news_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[gallery_content_type]' )->value();
	return power_news_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}


/**
 * Check if gallery section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if about section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_about_us_section_enabletest( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[about_us_section_enable]' )->value() );
}

/*==================Team===============*/

/**
 * Check if team section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[team_section_enable]' )->value() );
}

/**
 * Check if team section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[team_content_type]' )->value();
	return power_news_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[team_content_type]' )->value();
	return power_news_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[team_content_type]' )->value();
	return power_news_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/*==================Event===============*/

/**
 * Check if event section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_events_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[events_section_enable]' )->value() );
}

/**
 * Check if event section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_events_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[events_content_type]' )->value();
	return power_news_pro_is_events_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if event section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_events_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[events_content_type]' )->value();
	return power_news_pro_is_events_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if event section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_events_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[events_content_type]' )->value();
	return power_news_pro_is_events_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if event section content type is event.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_events_section_content_events_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[events_content_type]' )->value();
	return power_news_pro_is_events_section_enable( $control ) && ( 'event' == $content_type );
}

/**
 * Check if event section content type is event category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_events_section_content_events_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[events_content_type]' )->value();
	return power_news_pro_is_events_section_enable( $control ) && ( 'event-category' == $content_type );
}

/*==================Testimonial===============*/

/**
 * Check if testimonial section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[testimonial_content_type]' )->value();
	return power_news_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[testimonial_content_type]' )->value();
	return power_news_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[testimonial_content_type]' )->value();
	return power_news_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[testimonial_content_type]' )->value();
	return power_news_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[testimonial_content_type]' )->value();
	return power_news_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[testimonial_content_type]' )->value();
	return power_news_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/*=======================career========================*/

/**
 * Check if career section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_career_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[career_section_enable]' )->value() );
}

/**
 * Check if career section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_career_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[career_content_type]' )->value();
	return power_news_pro_is_career_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if career section content type is course-category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_career_section_content_course_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[career_content_type]' )->value();
	return power_news_pro_is_career_section_enable( $control ) && ( 'course-category' == $content_type );
}

/*==================Latest Products===============*/

/**
 * Check if latest products section content type is product.
 *
 * @since Swingpress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */

function power_news_pro_is_latest_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[latest_products_section_enable]' )->value() );
}


/*==================Popular Products===============*/

function power_news_pro_is_popular_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[popular_products_section_enable]' )->value() );
}

function power_news_pro_is_popular_products_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[popular_products_content_type]' )->value();
	return power_news_pro_is_popular_products_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if popular product section content type is product.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_popular_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[popular_products_content_type]' )->value();
	return power_news_pro_is_popular_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if popular products section content type is product_cat.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_popular_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[popular_products_content_type]' )->value();
	return power_news_pro_is_popular_products_section_enable( $control ) && ( 'product_cat' == $content_type );
}

/**
 * Check if popular products section content type is recent_product.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_popular_products_section_content_popular_products_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[popular_products_content_type]' )->value();
	return power_news_pro_is_popular_products_section_enable( $control ) && ( 'recent_product' == $content_type );
}

/*=================Producs Collection================*/

/**
 * Check if product collection section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_products_collection_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[products_collection_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/*==================Recent Product===============*/

/**
 * Check if recent product section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_recent_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[recent_products_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/**
 * Check if recent product section content type is product.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_recent_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[recent_products_content_type]' )->value();
	return power_news_pro_is_recent_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if recent product section content type is product category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_recent_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[recent_products_content_type]' )->value();
	return power_news_pro_is_recent_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/*=================Featured Products================*/

/**
 * Check if featured products section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_featured_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[featured_products_section_enable]' )->value() ) && class_exists( 'WooCommerce' );
}

/*=================Services================*/

/**
 * Check if service section is enabled.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_our_services_section_enable( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[our_services_section_enable]' )->value() );
}


function power_news_pro_is_our_services_section_icon_enable( $control ) {
	$icon = $control->manager->get_setting( 'power_news_pro_theme_options[our_services_section_icon_enable]' )->value();
	return power_news_pro_is_our_services_section_enable( $control ) && ( true == $icon );
}
/**
 * Check if service section content type is post.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_our_services_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[our_services_content_type]' )->value();
	return power_news_pro_is_our_services_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_our_services_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[our_services_content_type]' )->value();
	return power_news_pro_is_our_services_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_our_services_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[our_services_content_type]' )->value();
	return power_news_pro_is_our_services_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Power News Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function power_news_pro_is_our_services_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[our_services_content_type]' )->value();
	return power_news_pro_is_our_services_section_enable( $control ) && ( 'category' == $content_type );
}

function power_news_pro_is_our_services_section_content_trip_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[our_services_content_type]' )->value();
	return power_news_pro_is_our_services_section_enable( $control ) && ( 'trip' == $content_type );
}

function power_news_pro_is_our_services_section_content_trip_types_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[our_services_content_type]' )->value();
	return power_news_pro_is_our_services_section_enable( $control ) && ( 'trip-types' == $content_type );
}

function power_news_pro_is_our_services_section_content_activity_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[our_services_content_type]' )->value();
	return power_news_pro_is_our_services_section_enable( $control ) && ( 'activity' == $content_type );
}

function power_news_pro_is_our_services_section_content_destination_enable( $control ) {
	$content_type = $control->manager->get_setting( 'power_news_pro_theme_options[our_services_content_type]' )->value();
	return power_news_pro_is_our_services_section_enable( $control ) && ( 'destination' == $content_type );
}

/*==================Banner Settings===============*/

function power_news_pro_is_banner_enable_on_single_page( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[single_post_hide_banner]' )->value() );
}

function power_news_pro_is_banner_enable_on_blog_page( $control ) {
	return ( $control->manager->get_setting( 'power_news_pro_theme_options[hide_banner]' )->value() );
}


/*==================Pro layout===============*/

function power_news_pro_is_default_layout( $control ) {
	$design = $control->manager->get_setting( 'power_news_pro_theme_options[home_layout]' )->value();
	return ( 'default-design' == $design );
}

/*==================Second layout===============*/
function power_news_pro_is_second_layout( $control ) {
	$design = $control->manager->get_setting( 'power_news_pro_theme_options[home_layout]' )->value();
	return ( 'second-design' == $design );
}

/*==================Third layout===============*/
function power_news_pro_is_third_layout( $control ) {
	$design = $control->manager->get_setting( 'power_news_pro_theme_options[home_layout]' )->value();
	return ( 'third-design' == $design );
}

/*==================Fourth layout===============*/
function power_news_pro_is_fourth_layout( $control ) {
	$design = $control->manager->get_setting( 'power_news_pro_theme_options[home_layout]' )->value();
	return ( 'fourth-design' == $design );
}