<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 * @return array An array of default values
 */

function power_news_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$power_news_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#212121',
		'header_tagline_color'			=> '#212121',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#ff4443',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'dark-version',
		'home_layout'					=> 'default-design',

		// header color options
		'secondary_menu_bg_color'		=> '#171616',
		'blog_info_bg_color'		    => '#111111',
		'primary_menu_hover_color'		=> '#e5383e',
		'topbar_menu_item_color'        => '#ffffff',
		'primary_menu_item_color'       => '#ffffff',
		'topbar_item_hover_color'       => '#e5383e',
		'blog_info_bg_img'       		=> '',

		// footer color options
		'footer_bg_color'               => '212121',
		'footer_widget_title_color'     => '212121',
		'footer_widget_content_color'   => '212121',
		'footer_widget_hover_color'    	=> '212121',


		// banner settings
		'banner_section_bg_color'       => '212121',
		'banner_title_color'            => '212121',
		'banner_anchor_text_color'      => '212121',
		'banner_text_color'             => '212121',
		'banner_text_align'             => 'left', 
		'banner_wrapper_padding_top'    => '', 
		'banner_wrapper_padding_buttom' => '', 

		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> (bool) false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> (bool) true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> (bool) true,
		'nav_search_enable'				=> (bool) true,

		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> (bool) true,
		'pagination_type'         		=> 'default',

		'banner_settings_enable'       => (bool) true,

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'power-news-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'power-news-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'power-news-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> (bool) true,

		// reset options
		'reset_options'      			=> (bool) false,
		
		// homepage options
		'enable_frontpage_content' 		=> (bool) false,

		// homepage sections sortable
		'all_sortable' 						=> 'breaking_news,featured_posts,about_us,latest_products,popular_products,products_collection,courses,gallery,promotion,recent_products,featured_products,team,events,career,testimonial,media_posts,our_services,latest_posts,popular_posts,most_viewed,posts_slider,multiple_posts,subscribe_us,related_posts',

		//default sortable
		'default_sortable' 				=> 'breaking_news,main_content,related_posts',

		//second sortable
		'second_sortable' 				=> 'main_content,subscribe_us,related_posts',

		// Third sortable
		'third_sortable' 				=> 'featured_posts,about_us,courses,gallery,promotion,team,events,career,testimonial,latest_posts',

		// Fourth sortable
		'fourth_sortable' 				=> 'featured_posts,about_us,latest_products,popular_products,products_collection,promotion,recent_products,featured_products,testimonial,our_services,latest_posts',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'power-news-pro' ),
		'single_post_hide_image'		=> (bool) false,
		'hide_image' 					=> (bool) false,
		'hide_category'					=> (bool) false,
		'hide_title' 					=> (bool) false,
		'hide_content' 					=> (bool) false,
		'hide_date' 					=> (bool) false,
		'hide_author' 				    => (bool) false,
		'hide_banner'					=> (bool) false,		
		
		// single post theme options
		'single_post_hide_banner'           => (bool) false,
		'single_post_hide_date' 			=> (bool) false,
		'single_post_hide_author'			=> (bool) false,
		'single_post_hide_category'			=> (bool) false,
		'single_post_hide_tags'				=> (bool) false,
		'single_post_hide_featured_image'	=> (bool) false,
		
		/* Front Page */
		
		// Topbar
		'topbar_section_enable'			=> (bool) false,
		'secondary_menu_enable'			=> (bool) false,
		'social_menu_enable'			=> (bool) false,
		
		//Breaking News
		'breaking_news_section_enable'	=> (bool) true,
		'breaking_news_count'			=> 4,
		'breaking_news_content_type'	=> 'post',
		'breaking_news_title'			=> esc_html__('Breaking News', 'power-news-pro'),

		// Featured post
		'featured_posts_section_enable' => (bool) true,
		'featured_posts_content_type'	=> 'post',
		'featured_posts_count'			=> 2,
		'featured_posts_btn_txt'        => esc_html__('Purchase','power-news-pro'),
		'featured_posts_btn_alt_txt'    => esc_html__('View More','power-news-pro'),

		// Media post
		'media_post_title'			    => esc_html__( 'Media News', 'power-news-pro' ),
		'media_post_section_enable'     => (bool) true,
		'media_post_content_type'	    => 'post',
		'media_post_count'			    => 3,

		// Latest post
		'latest_post_title'			    => esc_html__( 'Latest News', 'power-news-pro' ),
		'latest_post_section_enable'    => (bool) true,
		'latest_post_content_type'	    => 'post',
		'latest_post_count'			    => 4,
		'latest_post_column'            => 'col-3',

		// Popular post
		'popular_post_title'		    => esc_html__( 'Travel News', 'power-news-pro' ),
		'popular_post_section_enable'   => (bool) true,
		'popular_post_content_type'	    => 'post',
		'popular_post_count'		    => 3,

		// Most viewd post
		'most_viewed_title'			    => esc_html__( 'Tech News', 'power-news-pro' ),
		'most_viewed_section_enable'    => (bool) true,
		'most_viewed_content_type'	    => 'post',
		'most_viewed_count'			    => 3,

		// Slider post
		'news_posts_slider_title'			=> esc_html__( 'Interior Desgin', 'power-news-pro' ),
		'news_posts_slider_section_enable'  => (bool) true,
		'news_posts_slider_content_type'	=> 'post',
		'news_posts_slider_count'		    => 3,

		// Multi post 
		'multi_post_section_enable'		    => (bool) true,
		'multi_post_col1_title'			    => esc_html__( 'World News', 'power-news-pro' ),
		'multi_post_col1_count'			    => 3,
		'multi_post_col1_content_type'	    => 'post',
		'multi_post_col2_title'			    => esc_html__( 'Sport News', 'power-news-pro' ),
		'multi_post_col2_count'			    => 3,
		'multi_post_col2_content_type'	    => 'post',

		// Media posts
		'media_post_section_enable'		    => (bool) true,
		'media_post_title'				    => esc_html__( 'Media Post', 'power-news-pro' ),
		'media_video_post_title'		    => esc_html__( 'How to learn any new programming language quickly', 'power-news-pro' ),
		'media_post_count'				    => 4,
		'video_post_count'				    => 1,
		'media_post_content_type'		    => 'post',
		'media_video_post_content_type'     => 'post',

		// Related post
		'related_posts_title'				=> esc_html__( 'Related Posts', 'power-news-pro' ),
		'related_posts_section_enable'      => (bool) true,
		'related_posts_content_type'	    => 'post',
		'related_posts_count'			    => 3,
	
		
		// Trending News
		'trending_news_section_enable'	    => (bool) true,
		'trending_news_title'			    => esc_html__( 'Trending News Articles', 'power-news-pro' ),
		'trending_news_content_type'	    => 'category',
		'trending_news_count'			    => 4,


		// Promotion
	   'promotion_section_enable'			=> true,
	   'promotion_content_type'			    => 'page',
	   'promotion_title'					=> esc_html__( 'California Road Trip', 'power-news-pro' ),
	   'promotion_subtitle'				    => esc_html__( 'Music is a world within itself', 'power-news-pro' ),
	   'promotion_description'				=> esc_html__( 'Accumsan iaculis, ducimus rutrum donec eiusmod, habitant quaerat, accusantium aperiam blandit, volutpat pede aliquet, litora per? Odio natus eu commodo. Adipiscing justo, laboris', 'power-news-pro' ),

	   	// Subscribe Us
		'subscribe_us_section_enable'		=> true,
		'subscribe_us_sub_title'			=> esc_html__( 'Newsletter', 'power-news-pro' ),
		'subscribe_us_title'				=> esc_html__( 'STAY INFORMED', 'power-news-pro' ),
		'subscribe_us_bg_image'				=> get_template_directory_uri() .'/assets/uploads/business-subscribe-us.jpg',
		'subscribe_us_btn_title'			=> esc_html__( 'Subscribe Now', 'power-news-pro' ),

		// About Us
		'about_us_section_enable'			=> true,
		'about_us_content_type'			    => 'page',
		'about_us_btn_title'	            => esc_html__( 'Read More', 'power-news-pro' ),
		'about_us_title'					=> esc_html__( 'Popular', 'power-news-pro' ),
		'about_us_subtitle'				    => esc_html__( 'Artist of the Week', 'power-news-pro' ),
		'about_us_description'				=> esc_html__( 'Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit.', 'power-news-pro' ),

		// course
		'courses_section_enable'			=> (bool) true,
		'courses_title'					    => esc_html__( 'Popular Courses', 'power-news-pro' ),
		'courses_sub_title'          		=> esc_html__('Choose Your Desired Course','power-news-pro'),
		'courses_content_type'				=> 'post',
		'courses_column'                    => 'col-3',
		'courses_count'						=> 3,
		'courses_excerpt_length'			=> 25,
		'courses_btn_txt'                   => esc_html__('Read More','power-news-pro'),

		// Gallery
		'gallery_section_enable'		    => true,
		'gallery_content_type'			    => 'category',
		'gallery_count'					    => 6,
		'gallery_title'					    => esc_html__( 'College Events', 'power-news-pro' ),
		'gallery_subtitle'				    => esc_html__( 'Our Portfolio', 'power-news-pro' ),
		'gallery_btn_title'			        => esc_html__( 'View All Gallery', 'power-news-pro' ),

		//team 
		'team_section_enable'				=> true,
		'team_content_type'					=> 'page',
		'team_count'						=> 4,
		'team_column_layout'				=> 'col-4',
		'team_title'						=> esc_html__( 'Our Talented Team', 'power-news-pro' ),
		'team_sub_title'					=> esc_html__( 'Artists', 'power-news-pro' ),	
		'team_btn_label'					=> esc_html__( 'View All Team', 'power-news-pro' ),

		// Event
		'events_section_enable'			    => true,
		'events_content_type'			    => 'category',
		'events_count'					    => 3,
		'events_title'					    => esc_html__( 'Upcoming Events', 'power-news-pro' ),
		'events_subtitle'				    => esc_html__( 'Amazing shows around 2019', 'power-news-pro' ),
		'events_readmore'				    => esc_html__( 'Buy Ticket', 'power-news-pro' ),

		// testimonial
		'testimonial_section_enable'	    => true,
		'testimonial_content_type'		    => 'category',
		'testimonial_count'				    => 3,
		'testimonial_title'				    => esc_html__( 'Public Reviews', 'power-news-pro' ),
		'testimonial_subtitle'			    => esc_html__( 'Testimonials', 'power-news-pro' ),

		// ca
		'career_section_enable'			=> (bool) true,
		'career_autoplay'				=> (bool) false,
		'career_content_type'			=> 'category',
		'career_count'					=> 5,
		'career_sub_title'				=> esc_html__( 'New Opportunities', 'power-news-pro' ),
		'career_title'					=> esc_html__( 'Choose Careers', 'power-news-pro' ),
		'career_btn_title'				=> esc_html__( 'Explore all courses', 'power-news-pro' ),
		'career_post_btn'				=> esc_html__( 'Join Course', 'power-news-pro' ),

		// Featured Product
		'latest_products_section_enable'	  => true,
		'latest_products_count'				  => 2,
		'latest_products_content_type'		  => 'category',


		// recent Product
		'popular_products_section_enable'	   => true,
		'popular_products_title'			   => esc_html__( 'Popular Products', 'power-news-pro' ),
		'popular_products_sub_title'		   => esc_html__( 'Browse Products', 'power-news-pro' ),
		'popular_products_count'			   => 3,
		'popular_products_content_type'		   => 'product',

		//products_collection
		'products_collection_title'			   => esc_html__( 'Products Collection', 'power-news-pro' ),
		'products_collection_subtitle'		   => esc_html__( 'Browse Products', 'power-news-pro' ),
		'products_collection_section_enable'   => (bool) true,
		'products_collection_count'		       => 4,
		
		// Recent Product
		'recent_products_section_enable'	   => true,
		'recent_products_content_type'		   => 'product-category',
		'recent_products_count'				   => 3,
		'recent_products_title'				   => esc_html__( 'Recent Products', 'power-news-pro' ),
		'recent_products_subtitle'			   => esc_html__( 'Browse Products', 'power-news-pro' ),

		//featured_products
		'featured_products_section_enable'     => (bool) true,
		'featured_products_count'		       => 2,
		'featured_products_column'             => 'col-2',

		// service
		'our_services_section_enable'		   => true,
		'our_services_section_icon_enable'	   => true,
		'our_services_content_type'			   => 'category',
		'our_services_count'				   => 3,


	);

$output = apply_filters( 'power_news_pro_default_theme_options', $power_news_pro_default_options );

	// Sort array in ascending order, according to the key:
if ( ! empty( $output ) ) {
	ksort( $output );
}

return $output;
}