<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'power_news_pro_about_us_section', array(
	'title'             => esc_html__( 'About Us','power-news-pro' ),
	'description'       => esc_html__( 'About Section options.', 'power-news-pro' ),
	'panel'             => 'power_news_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			power_news_pro_is_third_layout( $control )
			||
			power_news_pro_is_fourth_layout( $control )
		);
	},
) );

// About content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[about_us_section_enable]', array(
	'default'			=> 	$options['about_us_section_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[about_us_section_enable]', array(
	'label'             => esc_html__( 'About Section Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_about_us_section',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[about_us_section_enable]', array(
		'selector'      => '.about-section .tooltiptext',
		'settings'      => 'power_news_pro_theme_options[about_us_section_enable]',
    ) );
}

// about subtitle setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[about_us_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_us_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[about_us_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_about_us_section',
	'active_callback' 	=> 'power_news_pro_is_about_us_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[about_us_subtitle]', array(
		'selector'            => '#power_news_pro_about_us_section p.section-subtitle',
		'settings'            => 'power_news_pro_theme_options[about_us_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_about_us_subtitle_partial',
    ) );
}


// About content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[about_us_content_type]', array(
	'default'          	=> $options['about_us_content_type'],
	'sanitize_callback' => 'power_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[about_us_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'power-news-pro' ),
	'section'           => 'power_news_pro_about_us_section',
	'type'				=> 'select',
	'active_callback' 	=> 'power_news_pro_is_about_us_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'power-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'power-news-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'power-news-pro' ),
	),
) );

// about pages drop down chooser control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[about_us_content_page]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_page',
) );

$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[about_us_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'power-news-pro' ),
	'section'           => 'power_news_pro_about_us_section',
	'choices'			=> power_news_pro_page_choices(),
	'active_callback'	=> 'power_news_pro_is_about_us_section_content_page_enable',
) ) );

// about posts drop down chooser control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[about_us_content_post]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_page',
) );

$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[about_us_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'power-news-pro' ),
	'section'           => 'power_news_pro_about_us_section',
	'choices'			=> power_news_pro_post_choices(),
	'active_callback'	=> 'power_news_pro_is_about_us_section_content_post_enable',
) ) );

// about title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[about_us_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['about_us_title'],
) );

$wp_customize->add_control( 'power_news_pro_theme_options[about_us_title]', array(
	'label'           	=> esc_html__( 'Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_about_us_section',
	'active_callback' 	=> 'power_news_pro_is_about_us_section_content_custom_enable',
	'type'				=> 'text',
) );

// about description setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[about_us_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['about_us_description'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[about_us_description]', array(
	'label'           	=> esc_html__( 'Description', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_about_us_section',
	'active_callback' 	=> 'power_news_pro_is_about_us_section_content_custom_enable',
	'type'				=> 'textarea',
) );



// about image setting and control.
$wp_customize->add_setting( 'power_news_pro_theme_options[about_us_image]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'power_news_pro_theme_options[about_us_image]',
		array(
		'label'       		=> esc_html__( 'Image', 'power-news-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'power-news-pro' ), 512, 520 ),
		'section'     		=> 'power_news_pro_about_us_section',
		'active_callback'	=> 'power_news_pro_is_about_us_section_content_custom_enable',
) ) );

// about btn title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[about_us_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'           => $options['about_us_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[about_us_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_about_us_section',
	'active_callback' 	=> 'power_news_pro_is_about_us_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[about_us_btn_title]', array(
		'selector'            => '#power_news_pro_about_us_section .read-more .btn',
		'settings'            => 'power_news_pro_theme_options[about_us_btn_title]',
		'fallback_refresh'    => true,
		'container_inclusive' => false,
		'validate_callback'   => 'power_news_pro_about_us_btn_title_partial',
    ) );
}

// about btn link setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[about_us_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[about_us_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_about_us_section',
	'active_callback' 	=> 'power_news_pro_is_about_us_section_content_custom_enable',
	'type'				=> 'url',
) );