<?php
/**
 * Course Section options
 *
 * @package Theme Palace
 * @subpackage  Power News Pro
 * @since  Power News Pro 1.0.0
 */

// Add Course section
$wp_customize->add_section( 'power_news_pro_courses_section',
	array(
		'title'             => esc_html__( 'Course','power-news-pro' ),
		'description'       => esc_html__( 'Course Section options.', 'power-news-pro' ),
		'panel'             => 'power_news_pro_front_page_panel',
		'active_callback'   => function( $control ) {
			return ( 
				power_news_pro_is_third_layout( $control )			
			);
		},
	)
);

// Course content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[courses_section_enable]', 
	array(
		'default'			=> 	$options['courses_section_enable'],
		'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize,
	'power_news_pro_theme_options[courses_section_enable]',
		array(
			'label'             => esc_html__( 'Course Section Enable', 'power-news-pro' ),
			'section'           => 'power_news_pro_courses_section',
			'on_off_label' 		=> power_news_pro_switch_options(),
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[courses_section_enable]', array(
		'selector'            => '#power_news_pro_courses_section .tooltiptext',
		'settings'            => 'power_news_pro_theme_options[courses_section_enable]',
    ) );
}

// Course section sub title control and setting
$wp_customize->add_setting('power_news_pro_theme_options[courses_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'         => 'postMessage',
        'default'           => $options['courses_sub_title'],
    )
);

$wp_customize->add_control('power_news_pro_theme_options[courses_sub_title]',
    array(
        'label'             => esc_html__('Section Sub Title', 'power-news-pro'),
        'section'           => 'power_news_pro_courses_section',
        'type'              => 'text',
        'active_callback'   => 'power_news_pro_is_courses_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[courses_sub_title]',
        array(
            'selector'            => '#power_news_pro_courses_section .section-header p.section-subtitle',
            'settings'            => 'power_news_pro_theme_options[courses_sub_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'power_news_pro_courses_sub_title_partial',
        )
    );
}

// courses title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[courses_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['courses_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'power_news_pro_theme_options[courses_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'power-news-pro' ),
        'section'           => 'power_news_pro_courses_section',
        'active_callback'   => 'power_news_pro_is_courses_section_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[courses_title]',
        array(
            'selector'            => '#power_news_pro_courses_section .section-header h2.section-title',
            'settings'            => 'power_news_pro_theme_options[courses_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'power_news_pro_courses_title_partial',
        )
    );
}

// courses column control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[courses_column]',
	array(
		'default'          	=> $options['courses_column'],
		'sanitize_callback' => 'power_news_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'power_news_pro_theme_options[courses_column]',
	array(
		'label'             => esc_html__( 'Column Layout', 'power-news-pro' ),
		'section'           => 'power_news_pro_courses_section',
		'type'				=> 'select',
		'choices'			=> array( 
			'col-1'		=> esc_html__( 'One Column', 'power-news-pro' ),
			'col-2'		=> esc_html__( 'Two Column', 'power-news-pro' ),
			'col-3'		=> esc_html__( 'Three Column', 'power-news-pro' ),
		),
	)
);

// Course number control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[courses_count]',
	array(
		'default'          	=> $options['courses_count'],
		'sanitize_callback' => 'power_news_pro_sanitize_number_range',
		'validate_callback' => 'power_news_pro_validate_courses_count',
	)
);

$wp_customize->add_control( 'power_news_pro_theme_options[courses_count]',
	array(
		'label'             => esc_html__( 'Number of Post', 'power-news-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
		'section'           => 'power_news_pro_courses_section',
		'active_callback'   => 'power_news_pro_is_courses_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 6,
			'style' => 'width: 100px;'
		),
	)
);

// Course content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[courses_content_type]',
	array(
		'default'          	=> $options['courses_content_type'],
		'sanitize_callback' => 'power_news_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'power_news_pro_theme_options[courses_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'power-news-pro' ),
		'section'           => 'power_news_pro_courses_section',
		'type'				=> 'select',
		'active_callback' 	=> 'power_news_pro_is_courses_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'power-news-pro' ),
			'post' 		=> esc_html__( 'Post', 'power-news-pro' ),
			'category' 	=> esc_html__( 'Category', 'power-news-pro' ),
		),
	)
);


for ( $i = 1; $i <= $options['courses_count']; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[courses_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'power_news_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize,
		'power_news_pro_theme_options[courses_content_page_'. $i .']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Page: %d', 'power-news-pro'), $i ),
				'section'           => 'power_news_pro_courses_section',
				'choices'			=> power_news_pro_page_choices(),
				'active_callback'	=> 'power_news_pro_is_courses_section_content_page_enable',
			)
		)
	);

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[courses_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'power_news_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize,
		'power_news_pro_theme_options[courses_content_post_'. $i .']',
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'power-news-pro'), $i ),
				'section'           => 'power_news_pro_courses_section',
				'choices'			=> power_news_pro_post_choices(),
				'active_callback'	=> 'power_news_pro_is_courses_section_content_post_enable',
			)
		)
	);

	// power_news_pro_Customize_Horizontal_Line
    $wp_customize->add_setting('power_news_pro_theme_options[courses_separator'. $i .']',
		array(
			'sanitize_callback'      => 'power_news_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new power_news_pro_Customize_Horizontal_Line($wp_customize,
		'power_news_pro_theme_options[courses_separator'. $i .']',
			array(
				'active_callback'       => 'power_news_pro_is_courses_section_separator_enable',
				'type'                  =>'hr',
				'section'               =>'power_news_pro_courses_section',
			)
		)
	);

endfor;

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[courses_category]',
	array(
		'sanitize_callback' => 'power_news_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'power_news_pro_theme_options[courses_category]', 
		array(
			'label'             => esc_html__( 'Select Categories', 'power-news-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'power-news-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'power_news_pro_courses_section',
			'active_callback'	=> 'power_news_pro_is_courses_section_content_category_enable',
		)
	)
); 

// Course Excerpt length setting and control.
$wp_customize->add_setting( 'power_news_pro_theme_options[courses_excerpt_length]',
	array(
		'sanitize_callback' => 'power_news_pro_sanitize_number_range',
		'default'			=> $options['courses_excerpt_length'],
	)
);

$wp_customize->add_control( 'power_news_pro_theme_options[courses_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'power-news-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Course section', 'power-news-pro' ),
		'section'     		=> 'power_news_pro_courses_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'power_news_pro_is_courses_section_enable',
	)
);


//courses_btn_txt
$wp_customize->add_setting('power_news_pro_theme_options[courses_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['courses_btn_txt'],
    )
);

$wp_customize->add_control('power_news_pro_theme_options[courses_btn_txt]',
    array(
        'section'			=> 'power_news_pro_courses_section',
        'label'				=> esc_html__( 'Button Text:', 'power-news-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'power_news_pro_is_courses_section_enable'
    )
);