<?php
/**
 * Event Section options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

// Add Event section
$wp_customize->add_section( 'power_news_pro_events_section', array(
	'title'             => esc_html__( 'Event','power-news-pro' ),
	'description'       => esc_html__( 'Event Section options.', 'power-news-pro' ),
	'panel'             => 'power_news_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
			power_news_pro_is_third_layout( $control )
		);
	},
) );

// Event content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[events_section_enable]', array(
	'default'			=> 	$options['events_section_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[events_section_enable]', array(
	'label'             => esc_html__( 'Event Section Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_events_section',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[events_section_enable]', array(
		'selector'            => '#power_news_pro_events_section .tooltiptext',
		'settings'            => 'power_news_pro_theme_options[events_section_enable]',
    ) );
}

// Event background image control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[events_bg_image]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'power_news_pro_theme_options[events_bg_image]',
		array(
		'label'       		=> esc_html__( 'Bg Image', 'power-news-pro' ),
		'section'     		=> 'power_news_pro_events_section',
		'active_callback'	=> 'power_news_pro_is_events_section_enable',
) ) );


// event title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[events_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['events_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[events_title]', array(
	'label'           	=> esc_html__( 'Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_events_section',
	'active_callback' 	=> 'power_news_pro_is_events_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[events_title]', array(
		'selector'            => '#power_news_pro_events_section .section-title',
		'settings'            => 'power_news_pro_theme_options[events_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_events_title_partial',
    ) );
}


// event subtitle setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[events_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['events_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[events_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_events_section',
	'active_callback' 	=> 'power_news_pro_is_events_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[events_subtitle]', array(
		'selector'            => '#power_news_pro_events_section .section-subtitle',
		'settings'            => 'power_news_pro_theme_options[events_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_events_subtitle_partial',
    ) );
}

// Event content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[events_content_type]', array(
	'default'          	=> $options['events_content_type'],
	'sanitize_callback' => 'power_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[events_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'power-news-pro' ),
	'section'           => 'power_news_pro_events_section',
	'type'				=> 'select',
	'active_callback' 	=> 'power_news_pro_is_events_section_enable',
	'choices'			=> power_news_pro_event_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[events_count]', array(
	'default'          	=> $options['events_count'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'validate_callback' => 'power_news_pro_validate_events_count',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[events_count]', array(
	'label'             => esc_html__( 'Number of Event', 'power-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
	'section'           => 'power_news_pro_events_section',
	'active_callback'   => 'power_news_pro_is_events_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['events_count']; $i++ ) :

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[events_content_page_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[events_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'power-news-pro' ), $i ),
		'section'           => 'power_news_pro_events_section',
		'choices'			=> power_news_pro_page_choices(),
		'active_callback'	=> 'power_news_pro_is_events_section_content_page_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[events_content_post_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[events_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'power-news-pro' ), $i ),
		'section'           => 'power_news_pro_events_section',
		'choices'			=> power_news_pro_post_choices(),
		'active_callback'	=> 'power_news_pro_is_events_section_content_post_enable',
	) ) );

	// event posts drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[events_content_events_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[events_content_events_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Event %d', 'power-news-pro' ), $i ),
		'section'           => 'power_news_pro_events_section',
		'choices'			=> power_news_pro_event_choices(),
		'active_callback'	=> 'power_news_pro_is_events_section_content_events_enable',
	) ) );

	// event location setting and control
	$wp_customize->add_setting( 'power_news_pro_theme_options[events_location_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'power_news_pro_theme_options[events_location_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Event Location %d', 'power-news-pro' ), $i ),
		'section'        	=> 'power_news_pro_events_section',
		'type'				=> 'text',
		'active_callback'   => function( $control ) {
			return (
				power_news_pro_is_events_section_content_post_enable( $control )
				||
				power_news_pro_is_events_section_content_page_enable( $control )
				||
				power_news_pro_is_events_section_content_category_enable( $control )
			);
		}
	) );

		// event location setting and control
	$wp_customize->add_setting( 'power_news_pro_theme_options[events_time_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'power_news_pro_theme_options[events_time_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Event Time %d', 'power-news-pro' ), $i ),
		'section'        	=> 'power_news_pro_events_section',
		'type'				=> 'text',
		'active_callback'   => function( $control ) {
			return (
				power_news_pro_is_events_section_content_post_enable( $control )
				||
				power_news_pro_is_events_section_content_page_enable( $control )
				||
				power_news_pro_is_events_section_content_category_enable( $control )
			);
		}
	) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[events_content_category]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[events_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'power-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'power-news-pro' ),
	'section'           => 'power_news_pro_events_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_events_section_content_category_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[events_content_events_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[events_content_events_category]', array(
	'label'             => esc_html__( 'Select Event Category', 'power-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'power-news-pro' ),
	'section'           => 'power_news_pro_events_section',
	'taxonomy'			=> 'tp-event-category',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_events_section_content_events_category_enable'
) ) );