<?php
/**
* Featured Post Section options
*
* @package Theme Palace
* @subpackage Power News Pro
* @since Power News Pro 1.0.0
*/

// Add Featured Post section
$wp_customize->add_section( 'power_news_pro_featured_posts_section', array(
	'title'             => esc_html__( 'Featured Post','power-news-pro' ),
	'description'       => esc_html__( 'Featured Post Section options.', 'power-news-pro' ),
	'panel'             => 'power_news_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return ( 
			power_news_pro_is_default_layout( $control )
			||
			power_news_pro_is_second_layout( $control )
			||
			power_news_pro_is_third_layout( $control )
			||
			power_news_pro_is_fourth_layout( $control )
		);
	},
) );

// Featured Post content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[featured_posts_section_enable]', array(
	'default'			=> 	$options['featured_posts_section_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[featured_posts_section_enable]', array(
	'label'             => esc_html__( 'Featured Post Section Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_featured_posts_section',
	'on_off_label' 		=> power_news_pro_switch_options(),
	) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[featured_posts_section_enable]', array(
		'selector'      => '.featured-posts-section .tooltiptext',
		'settings'      => 'power_news_pro_theme_options[featured_posts_section_enable]',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[featured_posts_count]', array(
	'default'          	=> $options['featured_posts_count'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'validate_callback' => 'power_news_pro_validate_featured_posts_count',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[featured_posts_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'power-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
	'section'           => 'power_news_pro_featured_posts_section',
	'active_callback'   => 'power_news_pro_is_featured_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
	) );

// Featured Post content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[featured_posts_content_type]', array(
	'default'          	=> $options['featured_posts_content_type'],
	'sanitize_callback' => 'power_news_pro_sanitize_select',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[featured_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'power-news-pro' ),
	'section'           => 'power_news_pro_featured_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'power_news_pro_is_featured_posts_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'power-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'power-news-pro' ),
		'category' 	=> esc_html__( 'Category', 'power-news-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['featured_posts_count']; $i++ ) :
// featured posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
		) );

$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'power-news-pro' ), $i ),
	'section'           => 'power_news_pro_featured_posts_section',
	'choices'			=> power_news_pro_page_choices(),
	'active_callback'	=> 'power_news_pro_is_featured_posts_section_content_page_enable',
	) ) );

// featured posts posts drop down chooser control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
	'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'power-news-pro' ), $i ),
	'section'           => 'power_news_pro_featured_posts_section',
	'choices'			=> power_news_pro_post_choices(),
	'active_callback'	=> 'power_news_pro_is_featured_posts_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[featured_posts_content_category]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[featured_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'power-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'power-news-pro' ),
	'section'           => 'power_news_pro_featured_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_featured_posts_section_content_category_enable'
	) ) );


//featured posts_btn_txt
$wp_customize->add_setting('power_news_pro_theme_options[featured_posts_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['featured_posts_btn_txt'],
    )
);

$wp_customize->add_control('power_news_pro_theme_options[featured_posts_btn_txt]',
	array(
		'section'			=> 'power_news_pro_featured_posts_section',
		'label'				=> esc_html__( 'Button Text:', 'power-news-pro' ),
		'type'          	=>'text',
		'active_callback'   => function( $control ) {
			return ( 
				power_news_pro_is_featured_posts_section_enable( $control ) && power_news_pro_is_third_layout( $control )
				||
				power_news_pro_is_featured_posts_section_enable( $control ) && power_news_pro_is_fourth_layout( $control )
			);
		},
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[featured_posts_btn_txt]',
		array(
			'selector'            => '#power_news_pro_featured_posts_section .read-more .first',
			'settings'            => 'power_news_pro_theme_options[featured_posts_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'power_news_pro_featured_posts_btn_txt_partial',
		) 
	);
}

//featured posts btn alt txt
$wp_customize->add_setting('power_news_pro_theme_options[featured_posts_btn_alt_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['featured_posts_btn_alt_txt'],
    )
);

$wp_customize->add_control('power_news_pro_theme_options[featured_posts_btn_alt_txt]',
	array(
		'section'			=> 'power_news_pro_featured_posts_section',
		'label'				=> esc_html__( 'Button Alt Text:', 'power-news-pro' ),
		'type'          	=>'text',
		'active_callback'   => function( $control ) {
			return ( 
				power_news_pro_is_featured_posts_section_enable( $control ) && power_news_pro_is_third_layout( $control )
				||
				power_news_pro_is_featured_posts_section_enable( $control ) && power_news_pro_is_fourth_layout( $control )		
			);
		},
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[featured_posts_btn_alt_txt]',
		array(
			'selector'            => '#power_news_pro_featured_posts_section .read-more .second',
			'settings'            => 'power_news_pro_theme_options[featured_posts_btn_alt_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'power_news_pro_featured_posts_btn_alt_txt_partial',
		) 
	);
}

$wp_customize->add_setting( 'power_news_pro_theme_options[featured_posts_btn_alt_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'power_news_pro_theme_options[featured_posts_btn_alt_url]',
	array(
		'label'           	=> esc_html__( 'Button Alt URL', 'power-news-pro' ),
		'section'        	=> 'power_news_pro_featured_posts_section',
		'type'				=> 'url',
		'active_callback'   => function( $control ) {
			return ( 
				power_news_pro_is_featured_posts_section_enable( $control ) && power_news_pro_is_third_layout( $control )
				||
				power_news_pro_is_featured_posts_section_enable( $control ) && power_news_pro_is_fourth_layout( $control )		
			);
		},
	) 
);
