<?php
/**
 * Featured Products Section options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

if ( !class_exists('WooCommerce') ) {
    return;
}

// Add featured products section
$wp_customize->add_section( 'power_news_pro_featured_products_section', array(
	'title'             => esc_html__( 'Featured Products','power-news-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'power-news-pro' ),
	'panel'             => 'power_news_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
        	power_news_pro_is_fourth_layout( $control )
        	);
    },
) );

// featured products content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[featured_products_section_enable]', array(
	'default'			=> 	$options['featured_products_section_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[featured_products_section_enable]', array(
	'label'             => esc_html__( 'Featured Products Section Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_featured_products_section',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[featured_products_section_enable]', array(
		'selector'            => '#power_news_pro_featured_products_section .tooltiptext',
		'settings'            => 'power_news_pro_theme_options[featured_products_section_enable]',
    ) );
}

// featured product column control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[featured_products_column]',
	array(
		'default'          	=> $options['featured_products_column'],
		'sanitize_callback' => 'power_news_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'power_news_pro_theme_options[featured_products_column]',
	array(
		'label'             => esc_html__( 'Column Layout', 'power-news-pro' ),
		'section'           => 'power_news_pro_featured_products_section',
		'type'				=> 'select',
		'choices'			=> array( 
			'col-1'		=> esc_html__( 'One Column', 'power-news-pro' ),
			'col-2'		=> esc_html__( 'Two Column', 'power-news-pro' ),
			'col-3'		=> esc_html__( 'Three Column', 'power-news-pro' ),
		),
		'active_callback'   => 'power_news_pro_is_featured_products_section_enable',
	)
);

// content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[featured_products_count]', array(
	'default'          	=> $options['featured_products_count'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'validate_callback' => 'power_news_pro_validate_featured_products_count',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[featured_products_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'power-news-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
	'section'           => 'power_news_pro_featured_products_section',
	'active_callback'   => 'power_news_pro_is_featured_products_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 30,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['featured_products_count']; $i++ ) :

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'power_news_pro_theme_options[featured_products_content_product_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[featured_products_content_product_category_'.$i.']', array(
		'label'             => esc_html__( 'Select Featured Products Category ', 'power-news-pro' ).$i,
		'section'           => 'power_news_pro_featured_products_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'power_news_pro_is_featured_products_section_enable'
	) ) );

	$wp_customize->add_setting( 'power_news_pro_theme_options[featured_products_banner_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'power_news_pro_theme_options[featured_products_banner_title_'.$i.']', array(
		'label'           	=> esc_html__( 'Featured Product Title ', 'power-news-pro' ).$i,
		'section'        	=> 'power_news_pro_featured_products_section',
		'active_callback' 	=> 'power_news_pro_is_featured_products_section_enable',
		'type'				=> 'text',
	) );

	$wp_customize->add_setting( 'power_news_pro_theme_options[featured_products_banner_description_'.$i.']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'power_news_pro_theme_options[featured_products_banner_description_'.$i.']', array(
		'label'           	=> esc_html__( 'Featured Product Description ', 'power-news-pro' ).$i,
		'section'        	=> 'power_news_pro_featured_products_section',
		'active_callback' 	=> 'power_news_pro_is_featured_products_section_enable',
		'type'				=> 'textarea',
	) );

	$wp_customize->add_setting( 'power_news_pro_theme_options[featured_products_button_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'power_news_pro_theme_options[featured_products_button_'.$i.']', array(
		'label'           	=> esc_html__( 'Button Label ', 'power-news-pro' ).$i,
		'section'        	=> 'power_news_pro_featured_products_section',
		'active_callback' 	=> 'power_news_pro_is_featured_products_section_enable',
		'type'				=> 'text',
	) );

	// featured products hr setting and control
	$wp_customize->add_setting( 'power_news_pro_theme_options[featured_products_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Power_News_Pro_Customize_Horizontal_Line( $wp_customize, 'power_news_pro_theme_options[featured_products_hr_'. $i .']',
		array(
			'section'         => 'power_news_pro_featured_products_section',
			'active_callback' => 'power_news_pro_is_featured_products_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;