<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'power_news_pro_gallery_section', array(
    'title'             => esc_html__( 'Gallery','power-news-pro' ),
    'description'       => esc_html__( 'Gallery Section options.', 'power-news-pro' ),
    'panel'             => 'power_news_pro_front_page_panel',
    'active_callback'   => function( $control ) {
        return (
            power_news_pro_is_third_layout( $control )
        );
    },
) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[gallery_section_enable]', array(
    'default'           =>  $options['gallery_section_enable'],
    'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[gallery_section_enable]', array(
    'label'             => esc_html__( 'Gallery Section Enable', 'power-news-pro' ),
    'section'           => 'power_news_pro_gallery_section',
    'on_off_label'      => power_news_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[gallery_section_enable]', array(
        'selector'            => '.gallery-section .tooltiptext',
        'settings'            => 'power_news_pro_theme_options[gallery_section_enable]',
    ) );
}


// gallery title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[gallery_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['gallery_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[gallery_title]', array(
    'label'             => esc_html__( 'Title', 'power-news-pro' ),
    'section'           => 'power_news_pro_gallery_section',
    'active_callback'   => 'power_news_pro_is_gallery_section_enable',
    'type'              => 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[gallery_title]', array(
        'selector'            => '#power_news_pro_gallery_section .section-header .section-title',
        'settings'            => 'power_news_pro_theme_options[gallery_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'power_news_pro_gallery_title_partial',
    ) );
}

// gallery subtitle setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[gallery_subtitle]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['gallery_subtitle'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[gallery_subtitle]', array(
    'label'             => esc_html__( 'Sub Title', 'power-news-pro' ),
    'section'           => 'power_news_pro_gallery_section',
    'active_callback'   => 'power_news_pro_is_gallery_section_enable',
    'type'              => 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[gallery_subtitle]', array(
        'selector'            => '#power_news_pro_gallery_section .section-header .section-subtitle',
        'settings'            => 'power_news_pro_theme_options[gallery_subtitle]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'power_news_pro_gallery_subtitle_partial',
    ) );
}

// Gallery content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[gallery_content_type]', array(
    'default'           => $options['gallery_content_type'],
    'sanitize_callback' => 'power_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[gallery_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'power-news-pro' ),
    'section'           => 'power_news_pro_gallery_section',
    'type'              => 'select',
    'active_callback'   => 'power_news_pro_is_gallery_section_enable',
    'choices'           => power_news_pro_gallery_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[gallery_count]', array(
    'default'           => $options['gallery_count'],
    'sanitize_callback' => 'power_news_pro_sanitize_number_range',
    'validate_callback' => 'power_news_pro_validate_gallery_count',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[gallery_count]', array(
    'label'             => esc_html__( 'Number of Gallery', 'power-news-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
    'section'           => 'power_news_pro_gallery_section',
    'active_callback'   => 'power_news_pro_is_gallery_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

for ( $i = 1; $i <= $options['gallery_count']; $i++ ) :

    // gallery posts drop down chooser control and setting
    $wp_customize->add_setting( 'power_news_pro_theme_options[gallery_content_page_' . $i . ']', array(
        'sanitize_callback' => 'power_news_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[gallery_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Page %d', 'power-news-pro' ), $i ),
        'section'           => 'power_news_pro_gallery_section',
        'choices'           => power_news_pro_page_choices(),
        'active_callback'   => 'power_news_pro_is_gallery_section_content_page_enable',
    ) ) );

    // gallery posts drop down chooser control and setting
    $wp_customize->add_setting( 'power_news_pro_theme_options[gallery_content_post_' . $i . ']', array(
        'sanitize_callback' => 'power_news_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[gallery_content_post_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Post %d', 'power-news-pro' ), $i ),
        'section'           => 'power_news_pro_gallery_section',
        'choices'           => power_news_pro_post_choices(),
        'active_callback'   => 'power_news_pro_is_gallery_section_content_post_enable',
    ) ) );



endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[gallery_content_category]', array(
    'sanitize_callback' => 'power_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[gallery_content_category]', array(
    'label'             => esc_html__( 'Select Category', 'power-news-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'power-news-pro' ),
    'section'           => 'power_news_pro_gallery_section',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'power_news_pro_is_gallery_section_content_category_enable'
) ) );

// gallery vew all button title and url
$wp_customize->add_setting( 'power_news_pro_theme_options[gallery_btn_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default' => $options['gallery_btn_title'],
    'transport'         => 'postMessage',
    ) );

$wp_customize->add_control( 'power_news_pro_theme_options[gallery_btn_title]', array(
    'label'             => sprintf( esc_html__( 'Btn Title', 'power-news-pro' ) ),
    'section'           => 'power_news_pro_gallery_section',
    'active_callback'   => 'power_news_pro_is_gallery_section_enable',
    'type'              => 'text',
    ) );

    // Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[gallery_btn_title]', array(
        'selector'            => '#power_news_pro_gallery_section .read-more a',
        'settings'            => 'power_news_pro_theme_options[gallery_btn_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'power_news_pro_gallery_btn_title_partial',
    ) );
}

$wp_customize->add_setting( 'power_news_pro_theme_options[gallery_btn_url]', array(
    'sanitize_callback' => 'esc_url_raw',
    ) );

$wp_customize->add_control( 'power_news_pro_theme_options[gallery_btn_url]', array(
    'label'             => sprintf( esc_html__( 'Btn Url', 'power-news-pro' ) ),
    'section'           => 'power_news_pro_gallery_section',
    'active_callback'   => 'power_news_pro_is_gallery_section_enable',
    'type'              => 'url',
    ) );