<?php
/**
 * Latest Products Section options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

// Add lastest products section
$wp_customize->add_section( 'power_news_pro_latest_products_section', array(
    'title'             => esc_html__( 'Latest Products','power-news-pro' ),
    'description'       => esc_html__( 'Latest Products Section options.', 'power-news-pro' ),
    'panel'             => 'power_news_pro_front_page_panel',
    'active_callback'   => function( $control ) {
        return (
            power_news_pro_is_fourth_layout( $control )
        );
    },
) );

// lastest products content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[latest_products_section_enable]', array(
    'default'           =>  $options['latest_products_section_enable'],
    'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[latest_products_section_enable]', array(
    'label'             => esc_html__( 'Latest Products Section Enable', 'power-news-pro' ),
    'section'           => 'power_news_pro_latest_products_section',
    'on_off_label'      => power_news_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[latest_products_section_enable]', array(
        'selector'            => '#power_news_pro_latest_products_section .tooltiptext',
        'settings'            => 'power_news_pro_theme_options[latest_products_section_enable]',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[latest_products_count]', array(
    'default'           => $options['latest_products_count'],
    'sanitize_callback' => 'power_news_pro_sanitize_number_range',
    'validate_callback' => 'power_news_pro_validate_latest_products_count',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[latest_products_count]', array(
    'label'             => esc_html__( 'Number of Posts', 'power-news-pro' ),
    'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
    'section'           => 'power_news_pro_latest_products_section',
    'active_callback'   => 'power_news_pro_is_latest_products_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 4,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

for ( $i=1; $i <= $options['latest_products_count']; $i++ ) {

    // Add dropdown category setting and control.
    $wp_customize->add_setting(  'power_news_pro_theme_options[latest_products_content_latest_products_category_'.$i.']', array(
        'sanitize_callback' => 'absint',
    ) ) ;

    $wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[latest_products_content_latest_products_category_'.$i.']', array(
        'label'             => sprintf( esc_html__( 'Select Latest Products Category %d', 'power-news-pro' ), $i ),
        'section'           => 'power_news_pro_latest_products_section',
        'taxonomy'          => 'product_cat',
        'type'              => 'dropdown-taxonomies',
        'active_callback'   => 'power_news_pro_is_latest_products_section_enable'
    ) ) );
}


