<?php
/**
* Most Viewed Post Section options
*
* @package Theme Palace
* @subpackage Power News
* @since Power News 1.0.0
*/

// Add Most Viewed Post section
$wp_customize->add_section( 'power_news_pro_most_viewed_section', array(
	'title'             => esc_html__( 'Most Viewed Post','power-news-pro' ),
	'description'       => esc_html__( 'Most Viewed Post Section options.', 'power-news-pro' ),
	'panel'             => 'power_news_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return ( 
			power_news_pro_is_default_layout( $control )
			||
			power_news_pro_is_second_layout( $control )			
		);
	},
) );

// Most Viewed Post content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[most_viewed_section_enable]', array(
	'default'			=> 	$options['most_viewed_section_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[most_viewed_section_enable]', array(
	'label'             => esc_html__( 'Most Viewed Post Section Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_most_viewed_section',
	'on_off_label' 		=> power_news_pro_switch_options(),
	) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[most_viewed_section_enable]', array(
		'selector'      => '.most-viewed-section .tooltiptext',
		'settings'      => 'power_news_pro_theme_options[most_viewed_section_enable]',
    ) );
}

// most viewed title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[most_viewed_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['most_viewed_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[most_viewed_title]', array(
	'label'           	=> esc_html__( 'Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_most_viewed_section',
	'active_callback' 	=> 'power_news_pro_is_most_viewed_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[most_viewed_title]', array(
		'selector'            => '#power_news_pro_most_viewed_section div.section-header h2.section-title',
		'settings'            => 'power_news_pro_theme_options[most_viewed_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_most_viewed_title_partial',
		) );
}

// Most Viewed Post number control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[most_viewed_count]', array(
	'default'          	=> $options['most_viewed_count'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'validate_callback' => 'power_news_pro_validate_most_viewed_count',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[most_viewed_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'power-news-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
	'section'           => 'power_news_pro_most_viewed_section',
	'active_callback'   => 'power_news_pro_is_most_viewed_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
	) );

// Most Viewed Post content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[most_viewed_content_type]', array(
	'default'          	=> $options['most_viewed_content_type'],
	'sanitize_callback' => 'power_news_pro_sanitize_select',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[most_viewed_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'power-news-pro' ),
	'section'           => 'power_news_pro_most_viewed_section',
	'type'				=> 'select',
	'active_callback' 	=> 'power_news_pro_is_most_viewed_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'power-news-pro' ),
		'post' 		=> esc_html__( 'Post', 'power-news-pro' ),
		'category' 	=> esc_html__( 'Category', 'power-news-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['most_viewed_count']; $i++ ) :
// most viewed pages drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[most_viewed_content_page_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
		) );

$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[most_viewed_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'power-news-pro' ), $i ),
	'section'           => 'power_news_pro_most_viewed_section',
	'choices'			=> power_news_pro_page_choices(),
	'active_callback'	=> 'power_news_pro_is_most_viewed_section_content_page_enable',
	) ) );

// most viewed posts drop down chooser control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[most_viewed_content_post_' . $i . ']', array(
	'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[most_viewed_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'power-news-pro' ), $i ),
	'section'           => 'power_news_pro_most_viewed_section',
	'choices'			=> power_news_pro_post_choices(),
	'active_callback'	=> 'power_news_pro_is_most_viewed_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[most_viewed_content_category]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[most_viewed_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'power-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'power-news-pro' ),
	'section'           => 'power_news_pro_most_viewed_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_most_viewed_section_content_category_enable'
	) ) );