<?php
/**
* Multi Post Section options
*
* @package Theme Palace
* @subpackage Power News Pro
* @since Power News Pro 1.0.0
*/

// Add Multi Post section
$wp_customize->add_section( 'power_news_pro_multiple_posts_section', array(
	'title'             => esc_html__( 'Multi Post','power-news-pro' ),
	'description'       => esc_html__( 'Multi Post Section options.', 'power-news-pro' ),
	'panel'             => 'power_news_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return ( 
			power_news_pro_is_default_layout( $control )			
		);
	},
) );

// Multi Post content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_section_enable]', array(
	'default'			=> 	$options['multi_post_section_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
	) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[multi_post_section_enable]', array(
	'label'             => esc_html__( 'Multi Post Section Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'on_off_label' 		=> power_news_pro_switch_options(),
	) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[multi_post_section_enable]', array(
		'selector'      => '.multiple-posts-section .tooltiptext',
		'settings'      => 'power_news_pro_theme_options[multi_post_section_enable]',
    ) );
}

// multi posts title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_col1_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['multi_post_col1_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[multi_post_col1_title]', array(
	'label'           	=> esc_html__( 'Column 1 Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_multiple_posts_section',
	'active_callback' 	=> 'power_news_pro_is_multi_post_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[multi_post_col1_title]', array(
		'selector'            => '#power_news_pro_multiple_posts_section .col1 h2',
		'settings'            => 'power_news_pro_theme_options[multi_post_col1_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_multi_post_col1_title_partial',
		) );
}

// latest post number control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_col1_count]', array(
	'default'          	=> $options['multi_post_col1_count'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'validate_callback' => 'power_news_pro_validate_multi_post_col1_count',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[multi_post_col1_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'power-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'active_callback'   => 'power_news_pro_is_multi_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
	) );

// Multi Post content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_col1_content_type]', array(
	'default'          	=> $options['multi_post_col1_content_type'],
	'sanitize_callback' => 'power_news_pro_sanitize_select',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[multi_post_col1_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'power-news-pro' ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'power_news_pro_is_multi_post_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'power-news-pro' ),
		'page' 		=> esc_html__( 'Page', 'power-news-pro' ),
		'category' 	=> esc_html__( 'Category', 'power-news-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['multi_post_col1_count']; $i++ ) :
// multi posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_col1_content_page_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
		) );

$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[multi_post_col1_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'power-news-pro' ), $i ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'choices'			=> power_news_pro_page_choices(),
	'active_callback'	=> 'power_news_pro_is_multi_post_col1_section_content_page_enable',
	) ) );

// multi posts posts drop down chooser control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_col1_content_post_' . $i . ']', array(
	'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[multi_post_col1_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'power-news-pro' ), $i ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'choices'			=> power_news_pro_post_choices(),
	'active_callback'	=> 'power_news_pro_is_multi_post_col1_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[multi_post_col1_content_category]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[multi_post_col1_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'power-news-pro' ),
	'description'      	=> esc_html__( 'Note: Multi selected no of posts will be shown from selected category', 'power-news-pro' ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_multi_post_col1_section_content_category_enable'
	) ) );


    
// multi posts hr setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
	) );

$wp_customize->add_control( new Power_News_Pro_Customize_Horizontal_Line( $wp_customize, 'power_news_pro_theme_options[multi_post_hr]',
	array(
		'section'         => 'power_news_pro_multiple_posts_section',
		'active_callback' => 'power_news_pro_is_multi_post_section_enable',
        'type'			  => 'hr'
    )));
/**
* Multi Post column 2 Section options
*
* @package Theme Palace
* @subpackage Power News Pro
* @since Power News Pro 1.0.0
*/

// multi posts title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_col2_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['multi_post_col2_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[multi_post_col2_title]', array(
	'label'           	=> esc_html__( 'Column 2 Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_multiple_posts_section',
	'active_callback' 	=> 'power_news_pro_is_multi_post_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[multi_post_col2_title]', array(
		'selector'            => '#power_news_pro_multiple_posts_section .col2 h2',
		'settings'            => 'power_news_pro_theme_options[multi_post_col2_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_multi_post_col2_title_partial',
		) );
}

// latest post number control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_col2_count]', array(
	'default'          	=> $options['multi_post_col2_count'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'validate_callback' => 'power_news_pro_validate_multi_post_col2_count',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[multi_post_col2_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'power-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'active_callback'   => 'power_news_pro_is_multi_post_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
	) );

// Multi Post content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_col2_content_type]', array(
	'default'          	=> $options['multi_post_col2_content_type'],
	'sanitize_callback' => 'power_news_pro_sanitize_select',
	) );

$wp_customize->add_control( 'power_news_pro_theme_options[multi_post_col2_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'power-news-pro' ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'power_news_pro_is_multi_post_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'power-news-pro' ),
		'page' 		=> esc_html__( 'Page', 'power-news-pro' ),
		'category' 	=> esc_html__( 'Category', 'power-news-pro' ),
		),
	) );

for ( $i = 1; $i <= $options['multi_post_col2_count']; $i++ ) :
// multi posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_col2_content_page_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
		) );

$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[multi_post_col2_content_page_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'power-news-pro' ), $i ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'choices'			=> power_news_pro_page_choices(),
	'active_callback'	=> 'power_news_pro_is_multi_post_col2_section_content_page_enable',
	) ) );

// multi posts posts drop down chooser control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[multi_post_col2_content_post_' . $i . ']', array(
	'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[multi_post_col2_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'power-news-pro' ), $i ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'choices'			=> power_news_pro_post_choices(),
	'active_callback'	=> 'power_news_pro_is_multi_post_col2_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[multi_post_col2_content_category]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[multi_post_col2_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'power-news-pro' ),
	'description'      	=> esc_html__( 'Note: Multi selected no of posts will be shown from selected category', 'power-news-pro' ),
	'section'           => 'power_news_pro_multiple_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_multi_post_col2_section_content_category_enable'
	) ) );