<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'power_news_pro_our_services_section', array(
	'title'             => esc_html__( 'Services','power-news-pro' ),
	'description'       => esc_html__( 'Services Section options.', 'power-news-pro' ),
	'panel'             => 'power_news_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
            power_news_pro_is_fourth_layout( $control )
        );
    },
) );

// Service content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[our_services_section_enable]', array(
	'default'			=> 	$options['our_services_section_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[our_services_section_enable]', array(
	'label'             => esc_html__( 'Service Section Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_our_services_section',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[our_services_section_enable]', array(
		'selector'      => '#power_news_pro_our_services_section .tooltiptext',
		'settings'      => 'power_news_pro_theme_options[our_services_section_enable]',
    ) );
}


$wp_customize->add_setting( 'power_news_pro_theme_options[our_services_section_icon_enable]', array(
	'default'			=> 	$options['our_services_section_icon_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[our_services_section_icon_enable]', array(
	'label'             => esc_html__( 'Service Section Icon Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_our_services_section',
	'active_callback'   => 'power_news_pro_is_our_services_section_enable',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

// Servuce count number control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[our_services_count]', array(
	'default'          	=> $options['our_services_count'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'validate_callback' => 'power_news_pro_validate_our_services_count',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[our_services_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'power-news-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
	'section'           => 'power_news_pro_our_services_section',
	'active_callback'   => 'power_news_pro_is_our_services_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Service content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[our_services_content_type]', array(
	'default'          	=> $options['our_services_content_type'],
	'sanitize_callback' => 'power_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[our_services_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'power-news-pro' ),
	'section'           => 'power_news_pro_our_services_section',
	'type'				=> 'select',
	'active_callback' 	=> 'power_news_pro_is_our_services_section_enable',
	'choices'			=> power_news_pro_our_services_content_type(),
) );

for ( $i = 1; $i <= $options['our_services_count']; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[our_services_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Power_News_Pro_Icon_Picker( $wp_customize, 'power_news_pro_theme_options[our_services_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'power-news-pro' ), $i ),
		'section'           => 'power_news_pro_our_services_section',
		'active_callback'	=> 'power_news_pro_is_our_services_section_icon_enable',
	) ) );

	// service pages drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[our_services_content_page_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[our_services_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'power-news-pro' ), $i ),
		'section'           => 'power_news_pro_our_services_section',
		'choices'			=> power_news_pro_page_choices(),
		'active_callback'	=> 'power_news_pro_is_our_services_section_content_page_enable',
	) ) );

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[our_services_content_post_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[our_services_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'power-news-pro' ), $i ),
		'section'           => 'power_news_pro_our_services_section',
		'choices'			=> power_news_pro_post_choices(),
		'active_callback'	=> 'power_news_pro_is_our_services_section_content_post_enable',
	) ) );

	$wp_customize->add_setting( 'power_news_pro_theme_options[our_services_content_trip_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Power_News_Pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[our_services_content_trip_' . $i . ']', array(
		'label'             => sprintf ( esc_html__( 'Select Trip %d', 'power-news-pro' ), $i ),
		'section'           => 'power_news_pro_our_services_section',
		'choices'			=> power_news_pro_trip_choices(),
		'active_callback'	=> 'power_news_pro_is_our_services_section_content_trip_enable',
	) ) );

	// service hr setting and control
	$wp_customize->add_setting( 'power_news_pro_theme_options[our_services_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Power_News_Pro_Customize_Horizontal_Line( $wp_customize, 'power_news_pro_theme_options[our_services_hr_'. $i .']',
		array(
			'section'         => 'power_news_pro_our_services_section',
			'active_callback' => 'power_news_pro_is_our_services_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[our_services_content_category]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[our_services_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'power-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'power-news-pro' ),
	'section'           => 'power_news_pro_our_services_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_our_services_section_content_category_enable'
) ) );

$wp_customize->add_setting(  'power_news_pro_theme_options[our_services_content_trip_types]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[our_services_content_trip_types]', array(
	'label'             => esc_html__( 'Select Trip Types', 'power-news-pro' ),
	'section'           => 'power_news_pro_our_services_section',
	'taxonomy'			=> 'itinerary_types',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_our_services_section_content_trip_types_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[our_services_content_activity]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[our_services_content_activity]', array(
	'label'             => esc_html__( 'Select Activities', 'power-news-pro' ),
	'section'           => 'power_news_pro_our_services_section',
	'taxonomy'			=> 'activity',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_our_services_section_content_activity_enable'
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[our_services_content_destination]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Power_News_Pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[our_services_content_destination]', array(
	'label'             => esc_html__( 'Select Destinations', 'power-news-pro' ),
	'section'           => 'power_news_pro_our_services_section',
	'taxonomy'			=> 'travel_locations',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_our_services_section_content_destination_enable'
) ) );