<?php
/**
 * Products Collection Section options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

if ( !class_exists('WooCommerce') ) {
    return;
}

// Add products collection section
$wp_customize->add_section( 'power_news_pro_products_collection_section', array(
	'title'             => esc_html__( 'Products Collection','power-news-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'power-news-pro' ),
	'panel'             => 'power_news_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return (
        	power_news_pro_is_fourth_layout( $control )
        	);
    },
) );

// products collection content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[products_collection_section_enable]', array(
	'default'			=> 	$options['products_collection_section_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new power_news_pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[products_collection_section_enable]', array(
	'label'             => esc_html__( 'Products Collection Section Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_products_collection_section',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[products_collection_section_enable]', array(
		'selector'            => '#power_news_pro_products_collection_section .tooltiptext',
		'settings'            => 'power_news_pro_theme_options[products_collection_section_enable]',
    ) );
}

// latest posts title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[products_collection_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['products_collection_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[products_collection_title]', array(
	'label'           	=> esc_html__( 'Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_products_collection_section',
	'active_callback' 	=> 'power_news_pro_is_products_collection_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[products_collection_title]', array(
		'selector'      => '#power_news_pro_products_collection_section .section-header .section-title',
		'settings'      => 'power_news_pro_theme_options[products_collection_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_products_collection_title_partial',
    ) );
}


// latest posts subtitle setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[products_collection_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['products_collection_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[products_collection_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_products_collection_section',
	'active_callback' 	=> 'power_news_pro_is_products_collection_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[products_collection_subtitle]', array(
		'selector'      => '#power_news_pro_products_collection_section .section-header .section-subtitle',
		'settings'      => 'power_news_pro_theme_options[products_collection_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_products_collection_subtitle_partial',
    ) );
}

// content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[products_collection_count]', array(
	'default'          	=> $options['products_collection_count'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'validate_callback' => 'power_news_pro_validate_products_collection_count',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[products_collection_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'power-news-pro' ),
	'description'       => esc_html__( 'Note: Min 2 & Max 30. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
	'section'           => 'power_news_pro_products_collection_section',
	'active_callback'   => 'power_news_pro_is_products_collection_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 2,
		'max'	=> 30,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['products_collection_count']; $i++ ) :

	// Add dropdown category setting and control.
	$wp_customize->add_setting(  'power_news_pro_theme_options[products_collection_content_product_category_'.$i.']', array(
		'sanitize_callback' => 'absint',
	) ) ;

	$wp_customize->add_control( new power_news_pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[products_collection_content_product_category_'.$i.']', array(
		'label'             => esc_html__( 'Select Products Collection Category ', 'power-news-pro' ).$i,
		'section'           => 'power_news_pro_products_collection_section',
		'taxonomy'			=> 'product_cat',
		'type'              => 'dropdown-taxonomies',
		'active_callback'	=> 'power_news_pro_is_products_collection_section_enable'
	) ) );

	$wp_customize->add_setting( 'power_news_pro_theme_options[products_collection_banner_title_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'power_news_pro_theme_options[products_collection_banner_title_'.$i.']', array(
		'label'           	=> esc_html__( 'Featured Product Title ', 'power-news-pro' ).$i,
		'section'        	=> 'power_news_pro_products_collection_section',
		'active_callback' 	=> 'power_news_pro_is_products_collection_section_enable',
		'type'				=> 'text',
	) );

	$wp_customize->add_setting( 'power_news_pro_theme_options[products_collection_button_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'power_news_pro_theme_options[products_collection_button_'.$i.']', array(
		'label'           	=> esc_html__( 'Button Label ', 'power-news-pro' ).$i,
		'section'        	=> 'power_news_pro_products_collection_section',
		'active_callback' 	=> 'power_news_pro_is_products_collection_section_enable',
		'type'				=> 'text',
	) );

	// products collection hr setting and control
	$wp_customize->add_setting( 'power_news_pro_theme_options[products_collection_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new power_news_pro_Customize_Horizontal_Line( $wp_customize, 'power_news_pro_theme_options[products_collection_hr_'. $i .']',
		array(
			'section'         => 'power_news_pro_products_collection_section',
			'active_callback' => 'power_news_pro_is_products_collection_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;