<?php
/**
 * Recent Products Section options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

// Add recent product section
$wp_customize->add_section( 'power_news_pro_recent_products_section', array(
	'title'             => esc_html__( 'Recent Product','power-news-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'power-news-pro' ),
	'panel'             => 'power_news_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return (
        	power_news_pro_is_fourth_layout( $control )
		);
	},
) );

// recent product content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[recent_products_section_enable]', array(
	'default'			=> 	$options['recent_products_section_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new power_news_pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[recent_products_section_enable]', array(
	'label'             => esc_html__( 'Recent Product Section Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_recent_products_section',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[recent_products_section_enable]', array(
		'selector'            => '#power_news_pro_recent_products_section .tooltiptext',
		'settings'            => 'power_news_pro_theme_options[recent_products_section_enable]',
    ) );
}


// recent product title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[recent_products_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_products_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[recent_products_title]', array(
	'label'           	=> esc_html__( 'Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_recent_products_section',
	'active_callback' 	=> 'power_news_pro_is_recent_products_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[recent_products_title]', array(
		'selector'            => '#power_news_pro_recent_products_section .section-title',
		'settings'            => 'power_news_pro_theme_options[recent_products_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_recent_products_title_partial',
    ) );
}


// recent product subtitle setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[recent_products_subtitle]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['recent_products_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[recent_products_subtitle]', array(
	'label'           	=> esc_html__( 'Sub Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_recent_products_section',
	'active_callback' 	=> 'power_news_pro_is_recent_products_section_enable',
	'type'				=> 'text',
) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[recent_products_subtitle]', array(
		'selector'            => '#power_news_pro_recent_products_section .section-subtitle',
		'settings'            => 'power_news_pro_theme_options[recent_products_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_recent_products_subtitle_partial',
    ) );
}


// recent product content type control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[recent_products_content_type]', array(
	'default'          	=> $options['recent_products_content_type'],
	'sanitize_callback' => 'power_news_pro_sanitize_select',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[recent_products_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'power-news-pro' ),
	'section'           => 'power_news_pro_recent_products_section',
	'type'				=> 'select',
	'active_callback' 	=> 'power_news_pro_is_recent_products_section_enable',
	'choices'			=> power_news_pro_product_content_type(),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[recent_products_count]', array(
	'default'          	=> $options['recent_products_count'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'validate_callback' => 'power_news_pro_validate_recent_products_count',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[recent_products_count]', array(
	'label'             => esc_html__( 'Number of Product', 'power-news-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'power-news-pro' ),
	'section'           => 'power_news_pro_recent_products_section',
	'active_callback'   => 'power_news_pro_is_recent_products_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['recent_products_count']; $i++ ) :

	// recent product posts drop down chooser control and setting
	$wp_customize->add_setting( 'power_news_pro_theme_options[recent_products_content_product_' . $i . ']', array(
		'sanitize_callback' => 'power_news_pro_sanitize_page',
	) );

	$wp_customize->add_control( new power_news_pro_Dropdown_Chooser( $wp_customize, 'power_news_pro_theme_options[recent_products_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'power-news-pro' ), $i ),
		'section'           => 'power_news_pro_recent_products_section',
		'choices'			=> power_news_pro_product_choices(),
		'active_callback'	=> 'power_news_pro_is_recent_products_section_content_product_enable',
	) ) );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'power_news_pro_theme_options[recent_products_content_product_category]', array(
	'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new power_news_pro_Dropdown_Taxonomies_Control( $wp_customize,'power_news_pro_theme_options[recent_products_content_product_category]', array(
	'label'             => esc_html__( 'Select Product Category', 'power-news-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'power-news-pro' ),
	'section'           => 'power_news_pro_recent_products_section',
	'taxonomy'			=> 'product_cat',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'power_news_pro_is_recent_products_section_content_product_category_enable'
) ) );
