<?php
/**
 * Subscribe Us Section options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

// Add Subscribe Us section
$wp_customize->add_section( 'power_news_pro_subscribe_us_section', array(
	'title'             => esc_html__( 'Subscribe Us','power-news-pro' ),
	'description'       => esc_html__( 'Note: To activate this section you need to install Jetpack Plugin and activate subscription module.', 'power-news-pro' ),
	'panel'             => 'power_news_pro_front_page_panel',
	'active_callback'   => function( $control ) {
		return ( 
			power_news_pro_is_second_layout( $control )						
		);
	},
) );

// Subscribe Us content enable control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[subscribe_us_section_enable]', array(
	'default'			=> 	$options['subscribe_us_section_enable'],
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[subscribe_us_section_enable]', array(
	'label'             => esc_html__( 'Subscribe Us Section Enable', 'power-news-pro' ),
	'section'           => 'power_news_pro_subscribe_us_section',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[subscribe_us_section_enable]', array(
		'selector'            => '#power_news_pro_subscribe_us_section .tooltiptext',
		'settings'            => 'power_news_pro_theme_options[subscribe_us_section_enable]',
	) );
}


// Subscribe Us sub title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[subscribe_us_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscribe_us_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[subscribe_us_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_subscribe_us_section',
	'active_callback' 	=> 'power_news_pro_is_subscribe_us_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[subscribe_us_sub_title]', array(
		'selector'            => '#power_news_pro_subscribe_us_section .section-header p.section-subtitle',
		'settings'            => 'power_news_pro_theme_options[subscribe_us_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_subscribe_us_sub_title_partial',
    ) );
}

// Subscribe Us title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[subscribe_us_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscribe_us_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[subscribe_us_title]', array(
	'label'           	=> esc_html__( 'Title', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_subscribe_us_section',
	'active_callback' 	=> 'power_news_pro_is_subscribe_us_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[subscribe_us_title]', array(
		'selector'            => '#power_news_pro_subscribe_us_section .section-header h2.section-title',
		'settings'            => 'power_news_pro_theme_options[subscribe_us_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_subscribe_us_title_partial',
    ) );
}
// Subscribe Us  background image setting and control.
$wp_customize->add_setting( 'power_news_pro_theme_options[subscribe_us_bg_image]', array(
	'default'           =>$options['subscribe_us_bg_image'],
	'sanitize_callback' => 'power_news_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'power_news_pro_theme_options[subscribe_us_bg_image]',
		array(
		'label'       		=> esc_html__( 'Subscribe Us Background Image', 'power-news-pro'),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'power-news-pro' ), 1920, 600 ),
		'section'     		=> 'power_news_pro_subscribe_us_section',
		'active_callback'	=> 'power_news_pro_is_subscribe_us_section_enable',
) ) );

// Subscribe Us Business background image setting and control.
$wp_customize->add_setting( 'power_news_pro_theme_options[subscribe_us_bg_image]', array(
	'default'           =>$options['subscribe_us_bg_image'],
	'sanitize_callback' => 'power_news_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'power_news_pro_theme_options[subscribe_us_bg_image]',
		array(
		'label'       		=> esc_html__( 'Subscribe Us Background Image', 'power-news-pro'),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'power-news-pro' ), 1920, 600 ),
		'section'     		=> 'power_news_pro_subscribe_us_section',
		'active_callback'	=> 'power_news_pro_is_subscribe_us_section_enable',
) ) );

// Subscribe Us description setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[subscribe_us_description]', array(
	'sanitize_callback' => 'wp_kses_post',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[subscribe_us_description]', array(
	'label'           	=> esc_html__( 'Description', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_subscribe_us_section',
	'active_callback' 	=> 'power_news_pro_is_subscribe_us_section_enable',
	'type'				=> 'textarea',
) );

// Subscribe Us btn title setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[subscribe_us_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['subscribe_us_btn_title'],
) );

$wp_customize->add_control( 'power_news_pro_theme_options[subscribe_us_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'power-news-pro' ),
	'section'        	=> 'power_news_pro_subscribe_us_section',
	'active_callback' 	=> 'power_news_pro_is_subscribe_us_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[subscribe_us_btn_title]', array(
		'selector'            => '#power_news_pro_subscribe_us_section p#subscribe-submit',
		'settings'            => 'power_news_pro_theme_options[subscribe_us_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_subscribe_us_btn_title_partial',
    ) );
}

