<?php
/**
 * Loader options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

$wp_customize->add_section( 'power_news_pro_banner_settings', array(
	'title'            		=> esc_html__( 'Banner Settings','power-news-pro' ),
	'description'      		=> esc_html__( 'Banner section options.', 'power-news-pro' ),
	'panel'            		=> 'power_news_pro_theme_options_panel',
) );

// Sidebar position setting and control.
$wp_customize->add_setting( 'power_news_pro_theme_options[banner_settings_enable]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
	'default'             => $options['banner_settings_enable'],
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[banner_settings_enable]', array(
	'label'               => esc_html__( 'Banner Settings Enable', 'power-news-pro' ),
	'section'             => 'power_news_pro_banner_settings',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[banner_section_bg_color]', array(
	'default'           => $options['banner_section_bg_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[banner_section_bg_color]', array(
	'label'             => esc_html__( 'Banner Section Background Color', 'power-news-pro' ),
	'description'       => esc_html__( 'Note: This settings will be applied only when the hide banner options is enabled', 'power-news-pro' ),
	'section'           => 'power_news_pro_banner_settings',
	'active_callback'   => function( $control ) {
		return (
			power_news_pro_is_banner_enable_on_single_page( $control )
			||
			power_news_pro_is_banner_enable_on_blog_page( $control )
		);
	},
) ) );

// featured product column control and setting
$wp_customize->add_setting( 'power_news_pro_theme_options[banner_text_align]',
	array(
		'default'          	=> $options['banner_text_align'],
		'sanitize_callback' => 'power_news_pro_sanitize_select',
		'transport'			=> 'postMessage'

	)
);

$wp_customize->add_control( 'power_news_pro_theme_options[banner_text_align]',
	array(
		'label'             => esc_html__( 'Banner Text Align', 'power-news-pro' ),
		'description'       => esc_html__( 'Note: This option will be only visible if the hide banner setting is turned off', 'power-news-pro' ),
		'section'           => 'power_news_pro_banner_settings',
		'type'				=> 'select',
		'choices'			=> array( 
			'left'		=> esc_html__( 'Left', 'power-news-pro' ),
			'center'    => esc_html__( 'Center', 'power-news-pro' ),
			'right'		=> esc_html__( 'Right', 'power-news-pro' ),
		),
		'active_callback'   => function( $control ) {
			return (
				power_news_pro_is_banner_enable_on_single_page( $control )
				||
				power_news_pro_is_banner_enable_on_blog_page( $control )
			);
		},
	)
);

$wp_customize->add_setting( 'power_news_pro_theme_options[banner_title_color]', array(
	'default'           => $options['banner_title_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[banner_title_color]', array(
	'label'             => esc_html__( 'Banner Title Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_banner_settings',
) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[banner_anchor_text_color]', array(
	'default'           => $options['banner_anchor_text_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[banner_anchor_text_color]', array(
	'label'             => esc_html__( 'Banner Anchor Text Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_banner_settings',
) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[banner_text_color]', array(
	'default'           => $options['banner_text_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[banner_text_color]', array(
	'label'             => esc_html__( 'Banner Text Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_banner_settings',
) ) );

// banner wrapper padding settings
$wp_customize->add_setting( 'power_news_pro_theme_options[banner_wrapper_padding_top]', array(
	'default'          	=> $options['banner_wrapper_padding_top'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'power_news_pro_theme_options[banner_wrapper_padding_top]', array(
	'label'             => esc_html__( 'Padding Top', 'power-news-pro' ),
	'section'           => 'power_news_pro_banner_settings',
	'type'				=> 'number',
	'active_callback'   => function( $control ) {
		return (
			power_news_pro_is_banner_enable_on_single_page( $control )
			||
			power_news_pro_is_banner_enable_on_blog_page( $control )
		);
	},
) );

// banner wrapper padding settings
$wp_customize->add_setting( 'power_news_pro_theme_options[banner_wrapper_padding_buttom]', array(
	'default'          	=> $options['banner_wrapper_padding_buttom'],
	'sanitize_callback' => 'power_news_pro_sanitize_number_range',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( 'power_news_pro_theme_options[banner_wrapper_padding_buttom]', array(
	'label'             => esc_html__( 'Padding Buttom', 'power-news-pro' ),
	'section'           => 'power_news_pro_banner_settings',
	'type'				=> 'number',
	'active_callback'   => function( $control ) {
		return (
			power_news_pro_is_banner_enable_on_single_page( $control )
			||
			power_news_pro_is_banner_enable_on_blog_page( $control )
		);
	},
) );