<?php
/**
 * Footer options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

// Footer Section
$wp_customize->add_section( 'power_news_pro_section_footer',
	array(
		'title'      			=> esc_html__( 'Footer Options', 'power-news-pro' ),
		'priority'   			=> 900,
		'panel'      			=> 'power_news_pro_theme_options_panel',
	)
);

// footer text
$wp_customize->add_setting( 'power_news_pro_theme_options[copyright_text]',
	array(
		'default'       		=> $options['copyright_text'],
		'sanitize_callback'		=> 'power_news_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);
$wp_customize->add_control( 'power_news_pro_theme_options[copyright_text]',
    array(
		'label'      			=> esc_html__( 'Copyright Text', 'power-news-pro' ),
		'section'    			=> 'power_news_pro_section_footer',
		'type'		 			=> 'textarea',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'power_news_pro_theme_options[copyright_text]', array(
		'selector'            => '.site-info .copyright span',
		'settings'            => 'power_news_pro_theme_options[copyright_text]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'power_news_pro_copyright_text_partial',
    ) );
}

// scroll top visible
$wp_customize->add_setting( 'power_news_pro_theme_options[scroll_top_visible]',
	array(
		'default'       	=> $options['scroll_top_visible'],
		'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[scroll_top_visible]',
    array(
		'label'      		=> esc_html__( 'Display Scroll Top Button', 'power-news-pro' ),
		'section'    		=> 'power_news_pro_section_footer',
		'on_off_label' 		=> power_news_pro_switch_options(),
    )
) );

$wp_customize->add_setting( 'power_news_pro_theme_options[footer_bg_color]', array(
	'default'           => $options['footer_bg_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[footer_bg_color]', array(
	'label'             => esc_html__( 'Footer Background Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_section_footer',
) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[footer_widget_title_color]', array(
	'default'           => $options['footer_widget_title_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[footer_widget_title_color]', array(
	'label'             => esc_html__( 'Footer Widget Title Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_section_footer',
) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[footer_widget_content_color]', array(
	'default'           => $options['footer_widget_content_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[footer_widget_content_color]', array(
	'label'             => esc_html__( 'Footer Widget Content Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_section_footer',
) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[footer_widget_hover_color]', array(
	'default'           => $options['footer_widget_hover_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[footer_widget_hover_color]', array(
	'label'             => esc_html__( 'Footer Widget Hover Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_section_footer',
) ) );