<?php
/**
 * Menu options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

// Add sidebar section
$wp_customize->add_section( 'power_news_pro_menu', array(
	'title'             => esc_html__('Header Menu','power-news-pro'),
	'description'       => esc_html__( 'Header Menu options.', 'power-news-pro' ),
	'panel'             => 'nav_menus',
) );

// Menu sticky setting and control.
$wp_customize->add_setting( 'power_news_pro_theme_options[menu_sticky]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
	'default'           => $options['menu_sticky'],
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[menu_sticky]', array(
	'label'             => esc_html__( 'Make Menu Sticky', 'power-news-pro' ),
	'section'           => 'power_news_pro_menu',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

// search enable setting and control.
$wp_customize->add_setting( 'power_news_pro_theme_options[nav_search_enable]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_switch_control',
	'default'           => $options['nav_search_enable'],
) );

$wp_customize->add_control( new Power_News_Pro_Switch_Control( $wp_customize, 'power_news_pro_theme_options[nav_search_enable]', array(
	'label'             => esc_html__( 'Enable search', 'power-news-pro' ),
	'section'           => 'power_news_pro_menu',
	'on_off_label' 		=> power_news_pro_switch_options(),
) ) );

// ads image setting and control.
$wp_customize->add_setting( 'power_news_pro_theme_options[ads_image]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'power_news_pro_theme_options[ads_image]',
		array(
		'label'       		=> esc_html__( 'Ads Image', 'power-news-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'power-news-pro' ), 900, 100 ),
		'active_callback' 	=> 'power_news_pro_is_topbar_section_enable',
		'section'     		=> 'power_news_pro_menu',
) ) );

// ads link setting and control
$wp_customize->add_setting( 'power_news_pro_theme_options[ads_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'power_news_pro_theme_options[ads_url]', array(
	'label'           	=> esc_html__( 'Ads Url', 'power-news-pro' ),
	'active_callback' 	=> 'power_news_pro_is_topbar_section_enable',
	'section'        	=> 'power_news_pro_menu',
	'type'				=> 'url',
) );

$wp_customize->add_setting( 'power_news_pro_theme_options[topbar_hr]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Power_News_Pro_Customize_Horizontal_Line( $wp_customize, 'power_news_pro_theme_options[topbar_hr]',
	array(
		'section'         => 'power_news_pro_menu',
		'type'			  => 'hr',
	) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[secondary_menu_bg_color]', array(
	'default'           => $options['secondary_menu_bg_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[secondary_menu_bg_color]', array(
	'label'             => esc_html__( 'Menus Background Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_menu',
) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[topbar_menu_item_color]', array(
	'default'           => $options['topbar_menu_item_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[topbar_menu_item_color]', array(
	'label'             => esc_html__( 'Topbar Items Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_menu',
) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[topbar_item_hover_color]', array(
	'default'           => $options['topbar_item_hover_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[topbar_item_hover_color]', array(
	'label'             => esc_html__( 'Topbar Items Hover Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_menu',
) ) );


$wp_customize->add_setting( 'power_news_pro_theme_options[blog_info_hr]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Power_News_Pro_Customize_Horizontal_Line( $wp_customize, 'power_news_pro_theme_options[blog_info_hr]',
	array(
		'section'         => 'power_news_pro_menu',
		'type'			  => 'hr',
	) ) );

// ads image setting and control.
$wp_customize->add_setting( 'power_news_pro_theme_options[blog_info_bg_img]', array(
	'sanitize_callback' => 'power_news_pro_sanitize_image',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'power_news_pro_theme_options[blog_info_bg_img]',
		array(
		'label'       		=> esc_html__( 'Blog Info Background Image', 'power-news-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'power-news-pro' ), 900, 100 ),
		'section'     		=> 'power_news_pro_menu',
		// 'active_callback' 	=> 'power_news_pro_is_topbar_section_enable',
) ) );


$wp_customize->add_setting( 'power_news_pro_theme_options[blog_info_bg_color]', array(
	'default'           => $options['blog_info_bg_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[blog_info_bg_color]', array(
	'label'             => esc_html__( 'Blog Info Background Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_menu',
) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[primary_menu_hr]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Power_News_Pro_Customize_Horizontal_Line( $wp_customize, 'power_news_pro_theme_options[primary_menu_hr]',
	array(
		'section'         => 'power_news_pro_menu',
		'type'			  => 'hr',
	) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[primary_menu_hover_color]', array(
	'default'           => $options['primary_menu_hover_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'refresh'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[primary_menu_hover_color]', array(
	'label'             => esc_html__( 'Primary Menu Items Hover Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_menu',
) ) );

$wp_customize->add_setting( 'power_news_pro_theme_options[primary_menu_item_color]', array(
	'default'           => $options['primary_menu_item_color'],
	'sanitize_callback' => 'sanitize_hex_color',
	'transport'			=> 'postMessage'
) );

$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'power_news_pro_theme_options[primary_menu_item_color]', array(
	'label'             => esc_html__( 'Primary Menu Item Color', 'power-news-pro' ),
	'section'           => 'power_news_pro_menu',
) ) );