<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function power_news_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'power-news-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function power_news_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'power-news-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function power_news_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'power-news-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

function power_news_pro_product_choices() {
    $full_product_list = array();
    $product_id = array();
    $loop = new WP_Query(array('post_type' => array('product', 'product_variation'), 'posts_per_page' => -1));
    while ($loop->have_posts()) : $loop->the_post();
        $product_id[] = get_the_id();
    endwhile;
    wp_reset_postdata();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'power-news-pro' );
    foreach ( $product_id  as $id ) {
        $choices[ $id ] = get_the_title( $id );
    }
    return  $choices;
}

/**
 * List of trips for post choices.
 * @return Array Array of post ids and name.
 */
function power_news_pro_trip_choices() {
    $posts = get_posts( array( 'post_type' => 'itineraries', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'power-news-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of events for post choices.
 * @return Array Array of post ids and name.
 */
function power_news_pro_event_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'power-news-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}


if ( ! function_exists( 'power_news_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function power_news_pro_site_layout() {
        $power_news_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'power_news_pro_site_layout', $power_news_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'power_news_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function power_news_pro_selected_sidebar() {
        $power_news_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'power-news-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'power-news-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'power-news-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'power-news-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'power-news-pro' ),
        );

        $output = apply_filters( 'power_news_pro_selected_sidebar', $power_news_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'power_news_pro_typography_options' ) ) :
    function power_news_pro_typography_options(){
    $font_family_arr = array();
    $font_family_arr[''] = esc_html__( '--Default--', 'power-news-pro' );

    // Make the request
    $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

    if( is_wp_error( $request ) ) {
        return false; // Bail early
    }
     // Retrieve the data
    $body = wp_remote_retrieve_body( $request );
    $data = json_decode( $body );
    if ( ! empty( $data ) ) {
        foreach ( $data->items as $items => $fonts ) {
            $family_str_arr = explode( ' ', $fonts->family );
            $family_value = implode( '+', $family_str_arr );
            $font_family_arr[ $family_value ] = $fonts->family;
        }
    }

    return $font_family_arr;
}
endif;


if ( ! function_exists( 'power_news_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function power_news_pro_global_sidebar_position() {
        $power_news_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'power_news_pro_global_sidebar_position', $power_news_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'power_news_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function power_news_pro_sidebar_position() {
        $power_news_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'power_news_pro_sidebar_position', $power_news_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'power_news_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function power_news_pro_pagination_options() {
        $power_news_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'power-news-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'power-news-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'power-news-pro' ),
        );

        $output = apply_filters( 'power_news_pro_pagination_options', $power_news_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'power_news_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function power_news_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'power-news-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'power-news-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'power-news-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'power-news-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'power-news-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'power-news-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'power-news-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'power-news-pro' ),
        );
        return apply_filters( 'power_news_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'power_news_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function power_news_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'power-news-pro' ),
            'off'       => esc_html__( 'Disable', 'power-news-pro' )
        );
        return apply_filters( 'power_news_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'power_news_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function power_news_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'power-news-pro' ),
            'off'       => esc_html__( 'No', 'power-news-pro' )
        );
        return apply_filters( 'power_news_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'power_news_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function power_news_pro_sortable_sections() {
        $sections = array(
            'breaking_news'        => esc_html__( 'Breaking News', 'power-news-pro' ),
            'main_content'         => esc_html__( 'Main Content', 'power-news-pro' ),
            'related_posts'        => esc_html__( 'Related Post', 'power-news-pro' ),
            'latest_posts'         => esc_html__( 'Latest posts', 'power-news-pro' ),
            'featured_posts'       => esc_html__( 'Featured posts', 'power-news-pro' ),
            'promotion'            => esc_html__( 'Promotion', 'power-news-pro' ),
            'about_us'             => esc_html__( 'About Us', 'power-news-pro' ),
            'courses'              => esc_html__( 'Courses', 'power-news-pro' ),
            'gallery'              => esc_html__( 'Gallery', 'power-news-pro' ),
            'team'                 => esc_html__( 'Team', 'power-news-pro' ),
            'events'               => esc_html__( 'Events', 'power-news-pro' ),
            'career'               => esc_html__( 'Career', 'power-news-pro' ),
            'testimonial'          => esc_html__( 'Testimonial', 'power-news-pro' ),
            'latest_products'      => esc_html__( 'Latest Products', 'power-news-pro' ),
            'popular_products'     => esc_html__( 'Popular Products', 'power-news-pro' ),
            'products_collection'  => esc_html__( 'Products collection', 'power-news-pro' ),
            'recent_products'      => esc_html__( 'Recent Products', 'power-news-pro' ),
            'featured_products'    => esc_html__( 'Featured Products', 'power-news-pro' ),
            'our_services'         => esc_html__( 'Our Services', 'power-news-pro' ),
            'subscribe_us'         => esc_html__( 'Subscribe Us', 'power-news-pro' ),
        );
        return apply_filters( 'power_news_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'power_news_pro_weather_country_list' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function power_news_pro_weather_country_list() {
        $response = wp_remote_get( 'https://restcountries.eu/rest/v2/all' );
        try {
            $json = json_decode( $response['body'] );
     
        } catch ( Exception $ex ) {
            $json = null;
        } 
        $sections = array(
            $json->alpha2Code      => $json->name,
        );

        return apply_filters( 'power_news_pro_weather_country_list', $sections );
    }
endif;

if ( ! function_exists( 'power_news_pro_promotion_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function power_news_pro_promotion_content_type() {
        $power_news_pro_promotion_content_type = array(
            'page'      => esc_html__( 'Page', 'power-news-pro' ),
            'post'      => esc_html__( 'Post', 'power-news-pro' ),
        );


        $output = apply_filters( 'power_news_pro_promotion_content_type', $power_news_pro_promotion_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'power_news_pro_gallery_content_type' ) ) :
    /**
     * Gallery Options
     * @return array site gallery options
     */
    function power_news_pro_gallery_content_type() {
        $power_news_pro_gallery_content_type = array(
            'page'      => esc_html__( 'Page', 'power-news-pro' ),
            'post'      => esc_html__( 'Post', 'power-news-pro' ),
            'category'  => esc_html__( 'Category', 'power-news-pro' ),
        );

        $output = apply_filters( 'power_news_pro_gallery_content_type', $power_news_pro_gallery_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'power_news_pro_event_content_type' ) ) :
    /**
     * Special Offer Options
     * @return array site event options
     */
    function power_news_pro_event_content_type() {
        $power_news_pro_event_content_type = array(
            'page'      => esc_html__( 'Page', 'power-news-pro' ),
            'post'      => esc_html__( 'Post', 'power-news-pro' ),
            'category'  => esc_html__( 'Category', 'power-news-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $power_news_pro_event_content_type = array_merge( $power_news_pro_event_content_type, array(
                'event'   => esc_html__( 'Event', 'power-news-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'power-news-pro' ),
                ) );
        }

        $output = apply_filters( 'power_news_pro_event_content_type', $power_news_pro_event_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'power_news_pro_career_content_type' ) ) :
    /**
     * Package Options
     * @return array site career options
     */
    function power_news_pro_career_content_type() {
        $power_news_pro_career_content_type = array(
            'category'  => esc_html__( 'Category', 'power-news-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $power_news_pro_career_content_type = array_merge( $power_news_pro_career_content_type, array(
                'course-category'   => esc_html__( 'Course Category', 'power-news-pro' ),
                ) );
        }

        $output = apply_filters( 'power_news_pro_career_content_type', $power_news_pro_career_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'power_news_pro_featured_content_type' ) ) :
    /**
     * featured Options
     * @return array site featured options
     */
    function power_news_pro_featured_content_type() {
        $power_news_pro_featured_content_type = array(
            'category'  => esc_html__( 'Category', 'power-news-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $power_news_pro_featured_content_type = array_merge( $power_news_pro_featured_content_type, array(
                'trip-types'    => esc_html__( 'Trip Types', 'power-news-pro' ),
                'destination'   => esc_html__( 'Destination', 'power-news-pro' ),
                'activity'      => esc_html__( 'Activity', 'power-news-pro' ),
                ) );
        }

         if ( class_exists( 'WooCommerce' ) ) {

            $power_news_pro_featured_content_type = array_merge( $power_news_pro_featured_content_type, array(
                'product_cat'       => esc_html__( 'Product Category', 'power-news-pro' ),
                ) );
    
        }

        $output = apply_filters( 'power_news_pro_featured_content_type', $power_news_pro_featured_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'power_news_pro_latest_products_content_type' ) ) :
    /**
     * List of product_layout_similar_product options
     * @return array List of product_layout_similar_product options.
     */
    function power_news_pro_latest_products_content_type() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'power-news-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'power-news-pro' ),
            );
        }

        return apply_filters( 'power_news_pro_latest_product_content_type', $arr );
    }
endif;

if ( ! function_exists( 'power_news_pro_popular_products_content_type' ) ) :
    /**
     * List of product_layout_similar_product options
     * @return array List of product_layout_similar_product options.
     */
    function power_news_pro_popular_products_content_type() {
    
        if ( class_exists( 'WooCommerce' ) ) {
                $arr = array(
                'product'           => esc_html__( 'Product', 'power-news-pro' ),
                'product_cat'       => esc_html__( 'Product Category', 'power-news-pro' ),
            );
        }

        return apply_filters( 'power_news_pro_popular_products_content_type', $arr );
    }
endif;

if ( ! function_exists( 'power_news_pro_product_content_type' ) ) :
    /**
     * Product Options
     * @return array site product options
     */
    function power_news_pro_product_content_type() {
        $power_news_pro_product_content_type = array(
            'product'   => esc_html__( 'Product', 'power-news-pro' ),
            'product-category'   => esc_html__( 'Product Category', 'power-news-pro' ),
        );

        $output = apply_filters( 'power_news_pro_product_content_type', $power_news_pro_product_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'power_news_pro_our_services_content_type' ) ) :
    /**
     * our_services options
     * @return array site our_services options
     */
    function power_news_pro_our_services_content_type() {
        $power_news_pro_our_services_content_type = array(
            'page'      => esc_html__( 'Page', 'power-news-pro' ),
            'post'      => esc_html__( 'Post', 'power-news-pro' ),
            'category'  => esc_html__( 'Category', 'power-news-pro' ),
        );

        if ( class_exists( 'WP_Travel' ) ) {
            $power_news_pro_our_services_content_type = array_merge( $power_news_pro_our_services_content_type, array(
                'trip'          => esc_html__( 'Trip', 'power-news-pro' ),
                'trip-types'    => esc_html__( 'Trip Types', 'power-news-pro' ),
                'destination'   => esc_html__( 'Destination', 'power-news-pro' ),
                'activity'      => esc_html__( 'Activity', 'power-news-pro' ),
                ) );
        }

        $output = apply_filters( 'power_news_pro_our_services_content_type', $power_news_pro_our_services_content_type );


        return $output;
    }
endif;