<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */
if ( ! function_exists( 'power_news_pro_add_about_us_section' ) ) :
    /**
    * Add about section
    *
    *@since Power News Pro 1.0.0
    */
    function power_news_pro_add_about_us_section() {
    	$options = power_news_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_us_enable = apply_filters( 'power_news_pro_section_status', true, 'about_us_section_enable' );

        if ( true !== $about_us_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'power_news_pro_filter_about_us_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        power_news_pro_render_about_us_section( $section_details );
    }
endif;

if ( ! function_exists( 'power_news_pro_get_about_us_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Power News Pro 1.0.0
    * @param array $input about section details.
    */
    function power_news_pro_get_about_us_section_details( $input ) {
        $options = power_news_pro_get_theme_options();

        // Content type.
        $about_us_content_type  = $options['about_us_content_type'];
        
        $content = array();
        switch ( $about_us_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_us_title'] ) ? $options['about_us_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_us_description'] ) ? $options['about_us_description'] : '';
                $custom['image']        = ! empty( $options['about_us_image'] ) ? $options['about_us_image'] : '';
                $custom['url']          = ! empty( $options['about_us_btn_link'] ) ? $options['about_us_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_us_content_page'] ) ? $options['about_us_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_us_content_post'] ) ? $options['about_us_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $about_us_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = power_news_pro_trim_content( 50 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'power_news_pro_filter_about_us_section_details', 'power_news_pro_get_about_us_section_details' );


if ( ! function_exists( 'power_news_pro_render_about_us_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Power News Pro 1.0.0
   *
   */
function power_news_pro_render_about_us_section( $content_details = array() ) {
    $options  = power_news_pro_get_theme_options();
    
    if ( empty( $content_details ) ) {
        return;
    } ?>
        <div id="power_news_pro_about_us_section" class="about-section relative page-section same-background">
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    power_news_pro_section_tooltip( 'about-section-class' );
                    endif; ?>
                <?php foreach ($content_details as $content ): ?>
                    <article class="has-post-thumbnail">
                        <div class="featured-image">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="about"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <div class="section-header">
                                <?php if ( !empty( $options['about_us_subtitle'] ) ): ?>
                                    <p class="section-subtitle"><?php echo esc_html( $options['about_us_subtitle'] ); ?></p>
                                <?php endif ?>
                                
                                <h2 class="section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                            </div><!-- .section-header -->

                            <div class="entry-content">
                                <?php echo wp_kses_post( $content['excerpt'] ); ?>
                            </div><!-- .entry-content -->

                            <?php if ( !empty($content['url'] && $options['about_us_btn_title'] ) ) : ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html( $options['about_us_btn_title'] ); ?></a>
                            </div><!-- .read-more -->
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach ?>           
            </div><!-- .wrapper -->
        </div><!-- #about-section -->
    <?php }
endif;
