<?php
/**
 * Course section
 *
 * This is the template for the content of course section
 *
 * @package Theme Palace
 * @subpackage  Power News Pro
 * @since  Power News Pro 1.0.0
 */
if ( ! function_exists( 'power_news_pro_add_courses_section' ) ) :
    /**
    * Add course section
    *
    *@since  Power News Pro 1.0.0
    */
    function power_news_pro_add_courses_section() {
    	$options = power_news_pro_get_theme_options();
        // Check if course is enabled on frontpage
        $courses_enable = apply_filters( 'power_news_pro_section_status', true, 'courses_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design','third-design') ) ) {
            $courses_enable = false;
        }

        if ( true !== $courses_enable ) {
            return false;
        }
        // Get course section details
        $section_details = array();
        $section_details = apply_filters( 'power_news_pro_filter_courses_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render course section now.
        power_news_pro_render_courses_section( $section_details );
    }

endif;

if ( ! function_exists( 'power_news_pro_get_courses_section_details' ) ) :
    /**
    * course section details.
    *
    * @since  Power News Pro 1.0.0
    * @param array $input course section details.
    */
    function power_news_pro_get_courses_section_details( $input ) {
        $options = power_news_pro_get_theme_options();

        // Content type.
        $courses_content_type    = $options['courses_content_type'];
        $courses_count           = ! empty( $options['courses_count'] ) ? $options['courses_count'] : 4;
        
        $content = array();
        switch ( $courses_content_type ) {

            case 'page':
            $page_ids = array();

            for ( $i = 1; $i <= $courses_count; $i++ ) {
                if ( ! empty( $options['courses_content_page_' . $i] ) )
                    $page_ids[] = $options['courses_content_page_' . $i];
            }

            $args = array(
                'post_type'         => 'page',
                'post__in'          => ( array ) $page_ids,
                'posts_per_page'    => absint( $courses_count ),
                'orderby'           => 'post__in',
            );                    
            break;

            case 'post':
            $post_ids = array();

            for ( $i = 1; $i <= $courses_count; $i++ ) {
                if ( ! empty( $options['courses_content_post_' . $i] ) )
                    $post_ids[] = $options['courses_content_post_' . $i];
            }

            $args = array(
                'post_type'             => 'post',
                'post__in'              => ( array ) $post_ids,
                'posts_per_page'        => absint( $courses_count ),
                'orderby'               => 'post__in',
                'ignore_sticky_posts'   => true,
            );                    
            break;

            case 'category':
            $cat_id = ! empty( $options['courses_category'] ) ? $options['courses_category'] : '';
            $args = array(
                'post_type'             => 'post',
                'posts_per_page'        => absint( $courses_count ),
                'cat'                   => absint( $cat_id ),
                'ignore_sticky_posts'   => true,
            );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = power_news_pro_trim_content($options['courses_excerpt_length']);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// course section content details.
add_filter( 'power_news_pro_filter_courses_section_details', 'power_news_pro_get_courses_section_details' );


if ( ! function_exists( 'power_news_pro_render_courses_section' ) ) :
  /**
   * Start course section
   *
   * @return string course content
   * @since  Power News Pro 1.0.0
   *
   */
  function power_news_pro_render_courses_section( $content_details = array() ) {
    $options = power_news_pro_get_theme_options();

    if ( empty( $content_details ) ) {
        return;
    } ?>

    <div id="power_news_pro_courses_section" class="courses-section relative page-section">
        <?php if ( is_customize_preview()):
            power_news_pro_section_tooltip( 'courses-section-class' );
        endif; ?>
        <div class="wrapper">
            <div class="section-header">
                <p class="section-subtitle"><?php echo esc_html($options['courses_sub_title']); ?></p>
                <h2 class="section-title"><?php echo esc_html($options['courses_title']); ?></h2>
            </div><!-- .section-header -->
            <div class="section-content <?php echo esc_attr( $options['courses_column']); ?> clear">
                <?php foreach ( $content_details as $content ) : ?>
                    <article class="has-post-thumbnail">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->
                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                            </div><!-- .entry-content -->

                            <?php if(!empty($options['courses_btn_txt'])): ?>
                                <div class="more-link">
                                    <a href="<?php echo esc_url($content['url']); ?>" tabindex="0"><?php echo esc_html($options['courses_btn_txt']); ?><svg viewBox="0 0 292.359 292.359">
                                        <path d="M222.979,133.331L95.073,5.424C91.456,1.807,87.178,0,82.226,0c-4.952,0-9.233,1.807-12.85,5.424
                                        c-3.617,3.617-5.424,7.898-5.424,12.847v255.813c0,4.948,1.807,9.232,5.424,12.847c3.621,3.617,7.902,5.428,12.85,5.428
                                        c4.949,0,9.23-1.811,12.847-5.428l127.906-127.907c3.614-3.613,5.428-7.897,5.428-12.847
                                        C228.407,141.229,226.594,136.948,222.979,133.331z"></path>
                                    </svg></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                <?php endforeach; ?>

            </div><!-- .col-3 -->
        </div><!-- .wrapper -->
    </div>

    <?php
}    
endif;