<?php
/**
 * Event section
 *
 * This is the template for the content of event section
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */
if ( ! function_exists( 'power_news_pro_add_events_section' ) ) :
    /**
    * Add event section
    *
    *@since Power News Pro 1.0.0
    */
    function power_news_pro_add_events_section() {
    	$options = power_news_pro_get_theme_options();
        // Check if event is enabled on frontpage
        $events_enable = apply_filters( 'power_news_pro_section_status', true, 'events_section_enable' );

        if ( true !== $events_enable ) {
            return false;
        }
        // Get event section details
        $section_details = array();
        $section_details = apply_filters( 'power_news_pro_filter_events_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render event section now.
        power_news_pro_render_events_section( $section_details );
    }
endif;

if ( ! function_exists( 'power_news_pro_get_events_section_details' ) ) :
    /**
    * event section details.
    *
    * @since Power News Pro 1.0.0
    * @param array $input event section details.
    */
    function power_news_pro_get_events_section_details( $input ) {
        $options = power_news_pro_get_theme_options();

        // Content type.
        $events_content_type  = $options['events_content_type'];
        $events_count = ! empty( $options['events_count'] ) ? $options['events_count'] : 3;

        $content = array();
        switch ( $events_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $events_count; $i++ ) {
                    if ( ! empty( $options['events_content_page_' . $i] ) )
                        $page_ids[] = $options['events_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $events_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $events_count; $i++ ) {
                    if ( ! empty( $options['events_content_post_' . $i] ) )
                        $post_ids[] = $options['events_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $events_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['events_content_category'] ) ? $options['events_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $events_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'event':
                $page_ids = array();

                for ( $i = 1; $i <= $events_count; $i++ ) {
                    if ( ! empty( $options['events_content_events_' . $i] ) )
                        $page_ids[] = $options['events_content_events_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-event',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $events_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'event-category':
                $cat_id = ! empty( $options['events_content_events_category'] ) ? $options['events_content_events_category'] : '';
                $args = array(
                    'post_type'      => 'tp-event',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'tp-event-category',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $events_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = power_news_pro_trim_content( 5 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-150x150.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// event section content details.
add_filter( 'power_news_pro_filter_events_section_details', 'power_news_pro_get_events_section_details' );


if ( ! function_exists( 'power_news_pro_render_events_section' ) ) :
  /**
   * Start event section
   *
   * @return string event content
   * @since Power News Pro 1.0.0
   *
   */
   function power_news_pro_render_events_section( $content_details = array() ) {
        $options = power_news_pro_get_theme_options();
        $events_content_type  = $options['events_content_type'];
        $bg_image = !empty( $options['events_bg_image'] ) ? $options['events_bg_image'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="power_news_pro_events_section" class="event-section relative page-section" style="background-image: url('<?php echo esc_url( $bg_image ) ?>');">
                <div class="wrapper">
                    <?php if ( is_customize_preview()):
                    power_news_pro_section_tooltip( 'events-section-class' );
                    endif; ?>
                    <div class="section-header">
                        <?php if ( !empty( $options['events_subtitle'] ) ): ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['events_subtitle'] ); ?></p>
                        <?php endif ?>
                        <?php if ( !empty( $options['events_title'] ) ): ?>
                            <h2 class="section-title"><?php echo esc_html( $options['events_title'] ); ?></h2>
                        <?php endif ?>
                        
                    </div><!-- .section-header -->

                    <div class="section-content">
                        <?php $i=1; foreach ( $content_details as $content ) : 
                            if ( in_array( $events_content_type, array( 'event', 'event-category' ) ) && class_exists( 'TP_Education' ) ) :
                                $events_date     = get_tp_event_date( $content['id'] );
                                $events_location = get_post_meta( $content['id'], 'tp_event_location_value', true );
                                $events_start_time = get_tp_event_start_time( $content['id'] );
                                $events_end_time   = get_tp_event_end_time( $content['id'] );
                                $events_time       = $events_start_time . "-" . $events_end_time;
                            endif;
                            ?>
                            <article>
                                <div class="event-item clear">
                                    <?php if ( in_array( $events_content_type, array( 'event', 'event-category' ) ) && ! empty( $events_date ) ) : ?>
                                         <span class="posted-on">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" rel="bookmark">
                                                <time class="entry-date published updated" datetime="2018-04-06T11:33:16+00:00"><?php echo esc_html( $events_date ); ?></time>
                                            </a>
                                        </span><!-- .posted-on -->
                                        <?php else : ?>
                                            <?php power_news_pro_posted_on( $content['id'] ) ; ?>
                                    <?php endif; ?>

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        <?php if ( in_array( $events_content_type, array( 'event', 'event-category' ) ) && ! empty( $events_location ) ) : ?>
                                            <p class="event-location"><?php echo esc_html( $events_location ); ?></p>
                                            <?php else : ?>
                                               <?php if ( !empty($options['events_location_'.$i]) ): ?>
                                                <p class="location"><?php echo esc_html( $options['events_location_'.$i] ); ?></p>
                                            <?php endif ?>
                                        <?php endif; ?>
                                    </header>
                                    <?php if ( in_array( $events_content_type, array( 'event', 'event-category' ) ) && ! empty( $events_time ) ) : ?>
                                    <span class="venue-time"><?php echo esc_html( $events_time ); ?></span>
                                    <?php else: ?>
                                        <?php if ( !empty($options['events_time_'.$i]) ): ?>
                                            <span class="venue-time"><?php echo esc_html( $options['events_time_'.$i] ); ?></span>
                                        <?php endif ?>
                                    <?php endif; ?>
                                </div><!-- .event-item -->
                            </article>
                        <?php $i++; endforeach; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #events-section -->
       
    <?php }
endif;