<?php
/**
* Featured Post Section
*
* This is the template for the content of fetaured post section
*
* @package Theme Palace
* @subpackage Power News Pro
* @since Power News Pro 1.0.0
*/
if ( ! function_exists( 'power_news_pro_add_featured_posts_section' ) ) :

function power_news_pro_add_featured_posts_section(){

$options = power_news_pro_get_theme_options();

if($options['featured_posts_section_enable'] !== false ):

// Content type.
$featured_posts_content_type  = $options['featured_posts_content_type'];
$featured_posts_count = ! empty( $options['featured_posts_count'] ) ? $options['featured_posts_count'] : 3;

$content_details = array();
switch ( $featured_posts_content_type ) {

    case 'page':
    $page_ids = array();

    for ( $i = 1; $i <= $featured_posts_count; $i++ ) {
        if ( ! empty( $options['featured_posts_content_page_' . $i] ) )
            $page_ids[] = $options['featured_posts_content_page_' . $i];
    }

    $args = array(
        'post_type'         => 'page',
        'post__in'          => ( array ) $page_ids,
        'posts_per_page'    => absint( $featured_posts_count ),
        'orderby'           => 'post__in',
        );                    
    break;

    case 'post':
    $post_ids = array();

    for ( $i = 1; $i <= $featured_posts_count; $i++ ) {
        if ( ! empty( $options['featured_posts_content_post_' . $i] ) )
            $post_ids[] = $options['featured_posts_content_post_' . $i];
    }

    $args = array(
        'post_type'         => 'post',
        'post__in'          => ( array ) $post_ids,
        'posts_per_page'    => absint( $featured_posts_count ),
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                    
    break;

    case 'category':
    $cats_id = ! empty( $options['featured_posts_content_category'] ) ? $options['featured_posts_content_category'] : '';
    $args = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $featured_posts_count ),
        'cat'               => absint( $cats_id ),
        'ignore_sticky_posts'   => true,
        );                    
    break;

    case 'recent':
    $cat_ids = ! empty( $options['featured_posts_category_exclude'] ) ? $options['featured_posts_category_exclude'] : array();
    $args = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $featured_posts_count ),
        'category__not_in'  => ( array ) $cat_ids,
        'ignore_sticky_posts'   => true,
        );                    
    break;

    default:
    break;
}

// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) : 
    while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['title']     = get_the_title();
    $page_post['excerpt']   = power_news_pro_trim_content( 25 );
    $page_post['auth_id']   = get_the_author_meta('ID');
    $page_post['url']       = get_the_permalink();
    $page_post['image'] = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
array_push( $content_details, $page_post );
endwhile;
endif;
?>
<?php
$arrow = ( $options['home_layout'] == 'default-design' ) ? 'true' : 'false';
$dots  = ( $options['home_layout'] == 'default-design' ) ? 'false' : 'true';
$featured_posts_btn_alt_url = (!empty($options['featured_posts_btn_alt_url'])) ? $options['featured_posts_btn_alt_url'] : '';
?>
<div id="power_news_pro_featured_posts_section" class="featured-posts-section relative">
    <?php if ( is_customize_preview()):
        power_news_pro_section_tooltip( 'featured-posts-section-class' );
    endif; ?>
    <div class="featured-post-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": <?php echo esc_html( $dots ); ?>, "arrows":<?php echo esc_html( $arrow ); ?>, "autoplay": false, "draggable": true, "fade": false }'>
        <?php foreach ( $content_details as $content ) : ?>
            <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                <div class="overlay"></div>
                <?php if( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design' ) echo '<div class="wrapper">'; ?>
                <div class="entry-container">

                    <!-- third design layout -->
                    <?php if ( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design') : ?>
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>

                        <div class="entry-content">
                            <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                        </div><!-- .entry-content-->

                        <div class="read-more">
                            <?php if(!empty($options['featured_posts_btn_txt'])): ?>
                                <a href="<?php echo esc_url($content['url']); ?>" class="btn first"><?php echo esc_html($options['featured_posts_btn_txt']); ?></a>
                            <?php endif; ?>

                            <?php if(!empty($options['featured_posts_btn_alt_txt']) && !empty($featured_posts_btn_alt_url)): ?>
                            <a href="<?php echo esc_url($featured_posts_btn_alt_url); ?>" class="btn second"><?php echo esc_html($options['featured_posts_btn_alt_txt']); ?></a>
                        <?php endif; ?>
                    </div><!-- .read-more -->

                    <?php else: ?>

                    <div class="entry-meta">
                        <?php if ( $featured_posts_content_type !== 'page' ) : ?>
                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ); ?>
                            </span><!-- .cat-links -->
                        <?php endif; ?>
                        <?php power_news_pro_posted_on( $content['id'] ); ?>
                    </div><!-- .entry-meta -->

                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                    </header>
                    <?php echo power_news_pro_author( $content['auth_id'] ); ?>
                <?php endif; ?>
                </div><!-- .entry-container -->
                <?php if( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design' ) echo '</div>'; ?>
            </article>
    <?php endforeach; ?>
    </div><!-- .featured-slider -->
</div><!-- #power_featured_posts_section -->
<?php
endif;
}
endif;