<?php
/**
* Latest Posts Section
*
* This is the template for the content of latest posts section
*
* @package Theme Palace
* @subpackage Power News Pro
* @since Power News Pro 1.0.0
*/
if ( ! function_exists( 'power_news_pro_add_latest_posts_section' ) ) :

function power_news_pro_add_latest_posts_section(){
$options = power_news_pro_get_theme_options();

if($options['latest_post_section_enable'] !== false ):

    // Content type.
    $latest_post_content_type  = $options['latest_post_content_type'];
    $latest_post_count = ! empty( $options['latest_post_count'] ) ? $options['latest_post_count'] : 3;

    $content_details = array();
    switch ( $latest_post_content_type ) {

        case 'page':
        $page_ids = array();

        for ( $i = 1; $i <= $latest_post_count; $i++ ) {
            if ( ! empty( $options['latest_post_content_page_' . $i] ) )
                $page_ids[] = $options['latest_post_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( $latest_post_count ),
            'orderby'           => 'post__in',
        );                    
        break;

        case 'post':
        $post_ids = array();

        for ( $i = 1; $i <= $latest_post_count; $i++ ) {
            if ( ! empty( $options['latest_post_content_post_' . $i] ) )
                $post_ids[] = $options['latest_post_content_post_' . $i];
        }

        $args = array(
            'post_type'         => 'post',
            'post__in'          => ( array ) $post_ids,
            'posts_per_page'    => absint( $latest_post_count ),
            'orderby'           => 'post__in',
            'ignore_sticky_posts'   => true,
        );                    
        break;

        case 'category':
        $cats_id = ! empty( $options['latest_post_content_category'] ) ? $options['latest_post_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $latest_post_count ),
            'cat'               => absint( $cats_id ),
            'ignore_sticky_posts'   => true,
        );                    
        break;

        case 'recent':
        $cat_ids = ! empty( $options['latest_post_category_exclude'] ) ? $options['latest_post_category_exclude'] : array();
        $args = array(
            'post_type'         => 'post',
            'posts_per_page'    => absint( $latest_post_count ),
            'category__not_in'  => ( array ) $cat_ids,
            'ignore_sticky_posts'   => true,
        );                    
        break;

        default:
        break;
    }

    // Run The Loop.
    $query = new WP_Query( $args );
    if ( $query->have_posts() ) : 
        while ( $query->have_posts() ) : $query->the_post();
            $page_post['id']        = get_the_id();
            $page_post['title']     = get_the_title();
            $page_post['excerpt']   = power_news_pro_trim_content( 25 );
            $page_post['auth_id']   = get_the_author_meta('ID');
            $page_post['url']       = get_the_permalink();
            $page_post['image'] = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

            // Push to the main array.
            array_push( $content_details, $page_post );
        endwhile;
    endif;
    ?>

<div id="power_news_pro_latest_posts_section" class="latest-posts-section relative <?php if ($options['home_layout'] == 'third-design' || $options['home_layout'] == 'fourth-design' ) echo 'page-section' ?>">
    <?php if ( $options['home_layout'] !== 'default-design' ) echo '<div class="wrapper">' ?>
    <?php if ( is_customize_preview()):
        power_news_pro_section_tooltip( 'latest-posts-section-class' );
    endif; ?>
    <?php if ( ! empty( $options['latest_post_title'] ) ) : ?>
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $options['latest_post_title'] ); ?></h2>
        </div><!-- .section-header -->
    <?php endif; ?>

    <div class="section-content <?php echo esc_attr( $options['latest_post_column'] ); ?> clear">
        <?php foreach ( $content_details as $content ) : ?>
            <article>
                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                </div><!-- .featured-image -->

                <div class="entry-container">
                    <div class="entry-meta">
                        <?php power_news_pro_posted_on( $content['id'] ); ?>
                        <?php echo power_news_pro_author( $content['auth_id'] ); ?>
                    </div><!-- .entry-meta -->

                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                    </header>

                    <div class="entry-content">
                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                    </div><!-- .entry-content -->
                </div><!-- .entry-container -->
            </article>
        <?php endforeach; ?>
    </div><!-- .section-content -->
    <?php if ( $options['home_layout'] !== 'default-design' ) echo '</div>' ?>
</div><!-- #latest_post-posts -->
<?php endif; 
}
endif; ?>

