<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Power News Pros
 * @since Power News Pros 1.0.0
 */
if ( ! function_exists( 'power_news_pro_add_our_services_section' ) ) :
    /**
    * Add service section
    *
    *@since Power News Pros 1.0.0
    */
    function power_news_pro_add_our_services_section() {
        $options = power_news_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $our_services_enable = apply_filters( 'power_news_pro_section_status', true, 'our_services_section_enable' );

        if ( true !== $our_services_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'power_news_pro_filter_our_services_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        power_news_pro_render_our_services_section( $section_details );
    }
endif;

if ( ! function_exists( 'power_news_pro_get_our_services_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Power News Pros 1.0.0
    * @param array $input service section details.
    */
    function power_news_pro_get_our_services_section_details( $input ) {
        $options = power_news_pro_get_theme_options();

        // Content type.
        $our_services_content_type  = $options['our_services_content_type'];
        $our_services_count  = ! empty( $options['our_services_count'] ) ? $options['our_services_count'] : 3;
        
        $content = array();
        switch ( $our_services_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $our_services_count; $i++ ) {
                    if ( ! empty( $options['our_services_content_page_' . $i] ) )
                        $page_ids[] = $options['our_services_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => $our_services_count,
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $our_services_count; $i++ ) {
                    if ( ! empty( $options['our_services_content_post_' . $i] ) )
                        $post_ids[] = $options['our_services_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => $our_services_count,
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['our_services_content_category'] ) ? $options['our_services_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => $our_services_count,
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'trip':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $page_ids = array();

                for ( $i = 1; $i <= $our_services_count; $i++ ) {
                    if ( ! empty( $options['our_services_content_trip_' . $i] ) )
                        $page_ids[] = $options['our_services_content_trip_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'itineraries',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $our_services_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'trip-types':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['our_services_content_trip_types'] ) ? $options['our_services_content_trip_types'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'itinerary_types',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $our_services_count ),
                    );                    
            break;

            case 'destination':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;

                $cat_id = ! empty( $options['our_services_content_destination'] ) ? $options['our_services_content_destination'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'travel_locations',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $our_services_count ),
                    );                    
            break;

            case 'activity':
                if ( ! class_exists( 'WP_Travel' ) )
                    return;
                
                $cat_id = ! empty( $options['our_services_content_activity'] ) ? $options['our_services_content_activity'] : '';
                $args = array(
                    'post_type'      => 'itineraries',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'activity',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $our_services_count ),
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = power_news_pro_trim_content( 15 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'power_news_pro_filter_our_services_section_details', 'power_news_pro_get_our_services_section_details' );


if ( ! function_exists( 'power_news_pro_render_our_services_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Power News Pros 1.0.0
   *
   */
   function power_news_pro_render_our_services_section( $content_details = array() ) {
        $options = power_news_pro_get_theme_options();
        $i = 1;        

        if ( empty( $content_details ) ) {
            return;
        } 
        ?>
        <div id="power_news_pro_our_services_section" class="our-services-section relative page-section same-background">
            <div class="wrapper">
            <?php if ( is_customize_preview()):
                power_news_pro_section_tooltip( 'our-services-section-class' );
            endif; ?>
                <div class="section-content clear col-3">
                    <?php foreach ( $content_details as $i => $content ) : ?>

                        <article>
                            <div class="service-item-wrapper">
                             
                                <div class="entry-container">
                                    <?php if ( $options['our_services_section_icon_enable'] ): ?>
                                        <div class="icon-container">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>">
                                                <i class="fa <?php echo ! empty( $options['our_services_content_icon_' . ($i+1)] ) ? esc_attr( $options['our_services_content_icon_' . ($i+1)] ) : 'fa-cogs'; ?>"></i>
                                            </a>
                                        </div><!-- .service-icon -->
                                    <?php endif ?>                                

                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </div><!-- .service-item -->
                        </article>
                    <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div> 
        
    <?php }
endif;