<?php
/**
 * Popular Product Section
 *
 * This is the template for the content of popular products section
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */
if ( ! function_exists( 'power_news_pro_add_popular_products_section' ) ) :
    /**
    * Add popular products section
    *
    *@since Power News Pro 1.0.0
    */
    function power_news_pro_add_popular_products_section() {
        $options = power_news_pro_get_theme_options();
        // Check if popular products is enabled on frontpage
        $popular_products_enable = apply_filters( 'power_news_pro_section_status', true, 'popular_products_section_enable' );

        if ( true !== $popular_products_enable ) {
            return false;
        }
        // Get popular products section details
        $section_details = array();
        $section_details = apply_filters( 'power_news_pro_filter_popular_products_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render popular products section now.
        power_news_pro_render_popular_products_section( $section_details );
    }
endif;

if ( ! function_exists( 'power_news_pro_get_popular_products_section_details' ) ) :
    /**
    * popular products section details.
    *
    * @since Power News Pro 1.0.0
    * @param array $input popular products section details.
    */
    function power_news_pro_get_popular_products_section_details( $input ) {
        $options = power_news_pro_get_theme_options();

        // Content type.
        $popular_products_content_type  = $options['popular_products_content_type'];     
        $popular_products_count = ! empty( $options['popular_products_count'] ) ? $options['popular_products_count'] : 4; 
        
        $content = array();
        $content = array();
        switch ( $popular_products_content_type ) {

            case 'product':
                $product_ids = array();

                for ( $i = 1; $i <= $popular_products_count; $i++ ) {
                    if ( ! empty( $options['popular_products_content_product_' . $i] ) )
                        $product_ids[] = $options['popular_products_content_product_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $product_ids,
                    'posts_per_page'    => $popular_products_count,
                    'orderby'           => 'post__in',
                    );
            break;

            case 'product_cat':
                $cat_id = ! empty( $options['popular_products_content_product_category'] ) ? $options['popular_products_content_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $popular_products_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = power_news_pro_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// popular products section content details.
add_filter( 'power_news_pro_filter_popular_products_section_details', 'power_news_pro_get_popular_products_section_details' );


if ( ! function_exists( 'power_news_pro_render_popular_products_section' ) ) :
  /**
   * Start popular products section
   *
   * @return string popular products content
   * @since Power News Pro 1.0.0
   *
   */
   function power_news_pro_render_popular_products_section( $content_details = array() ) {
        $options = power_news_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="power_news_pro_popular_products_section" class="popular-products-section relative page-section">
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    power_news_pro_section_tooltip( 'popular-products-section-class' );
                endif; ?>
                <div class="section-header">
                    <?php if ( ! empty( $options['popular_products_title'] ) ) : ?>
                        <h2 class="section-title"><?php echo esc_html( $options['popular_products_title'] ); ?></h2>
                    <?php endif; ?>
                    <?php if ( ! empty( $options['popular_products_sub_title'] ) ) : ?>
                        <p class="section-subtitle"><?php echo esc_html( $options['popular_products_sub_title'] ); ?></p>
                    <?php endif; ?>
                </div><!-- .section-header -->

                <div class="section-content">
                    <ul class="products columns-3 product-slider" data-slick='{"slidesToShow": 4, "slidesToScroll": 4, "infinite": false, "speed": 1500, "dots": true, "arrows": true, "autoplay": false, "draggable": true, "fade": false }'>
                        <?php foreach ( $content_details as $content ): 
                            $image = $content['image'] == '' ? get_template_directory_uri().'/assets/uploads/no-featured-image-590x650.jpg' : $content['image'] ;
                            ?>
                            <li class="product featured-products">
                                <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                    <img src="<?php echo esc_url($image); ?>">
                                    <div class="product_meta">
                                        <?php 
                                        $terms = get_the_terms ( $content['id'], 'product_cat' );
                                        foreach ( $terms as $term ) { ?>
                                            <span class="posted_in">
                                                <a href="<?php echo esc_url( get_term_link( $term->term_id, 'product_cat' ) ) ?>"><?php echo esc_html( $term->name) ; ?></a>
                                            </span><!-- .posted_in -->

                                        <?php }
                                        ?>
                                    </div><!-- .product-meta -->
                                    <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ) ?></h2>
                                    <span class="price">
                                        <?php 
                                        $product = new WC_Product( $content['id'] );
                                        echo $product->get_price_html();
                                        ?>
                                    </span>
                                </a>
                                <a href="<?php echo do_shortcode( '[add_to_cart_url id="' . absint( $content['id'] ) . '"]' ); ?>" class="button product_type_simple add_to_cart_button ajax_add_to_cart"> 
                                    <?php esc_html_e('Add to cart', 'power-news-pro') ?>

                                </a>
                            </li>
                        <?php endforeach; ?>

                    </ul><!-- .product-slider -->
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>
        
    <?php }
endif;