<?php
/**
* Posts Slider Section
*
* This is the template for the content of posts slider section
*
* @package Theme Palace
* @subpackage Power News Pro
* @since Power News Pro 1.0.0
*/

$options = power_news_pro_get_theme_options();

if($options['news_posts_slider_section_enable'] !== false ):

// Content type.
$news_posts_slider_content_type  = $options['news_posts_slider_content_type'];
$news_posts_slider_count = ! empty( $options['news_posts_slider_count'] ) ? $options['news_posts_slider_count'] : 3;

$content_details = array();
switch ( $news_posts_slider_content_type ) {

    case 'page':
    $page_ids = array();

    for ( $i = 1; $i <= $news_posts_slider_count; $i++ ) {
        if ( ! empty( $options['news_posts_slider_content_page_' . $i] ) )
            $page_ids[] = $options['news_posts_slider_content_page_' . $i];
    }

    $args = array(
        'post_type'         => 'page',
        'post__in'          => ( array ) $page_ids,
        'posts_per_page'    => absint( $news_posts_slider_count ),
        'orderby'           => 'post__in',
        );                    
    break;

    case 'post':
    $post_ids = array();

    for ( $i = 1; $i <= $news_posts_slider_count; $i++ ) {
        if ( ! empty( $options['news_posts_slider_content_post_' . $i] ) )
            $post_ids[] = $options['news_posts_slider_content_post_' . $i];
    }

    $args = array(
        'post_type'         => 'post',
        'post__in'          => ( array ) $post_ids,
        'posts_per_page'    => absint( $news_posts_slider_count ),
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                    
    break;

    case 'category':
    $cats_id = ! empty( $options['news_posts_slider_content_category'] ) ? $options['news_posts_slider_content_category'] : '';
    $args = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $news_posts_slider_count ),
        'cat'               => absint( $cats_id ),
        'ignore_sticky_posts'   => true,
        );                    
    break;

    case 'recent':
    $cat_ids = ! empty( $options['news_posts_slider_category_exclude'] ) ? $options['news_posts_slider_category_exclude'] : array();
    $args = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $news_posts_slider_count ),
        'category__not_in'  => ( array ) $cat_ids,
        'ignore_sticky_posts'   => true,
        );                    
    break;

    default:
    break;
}

// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) : 
    while ( $query->have_posts() ) : $query->the_post();
    $page_post['id']        = get_the_id();
    $page_post['title']     = get_the_title();
    $page_post['excerpt']     = get_the_content();
    $page_post['auth_id']   = get_the_author_meta('ID');
    $page_post['url']       = get_the_permalink();
    $page_post['image'] = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

// Push to the main array.
array_push( $content_details, $page_post );
endwhile;
endif;
?>
<div id="power_news_pro_posts_slider_section" class="slider-section relative">
 <?php if ( is_customize_preview()):
    power_news_pro_section_tooltip( 'slider-section-class' );
endif; ?>
    <?php if ( ! empty( $options['news_posts_slider_title'] ) ) : ?>
        <div class="section-header">
            <h2 class="section-title"><?php echo esc_html( $options['news_posts_slider_title'] ); ?></h2>
        </div><!-- .section-header -->
    <?php endif; ?>

    <div class="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": false, "draggable": true, "fade": false }'>
        <?php foreach ( $content_details as $content ) : ?>
            <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                <div class="entry-container">
                    <div class="entry-meta">
                        <?php if ( $news_posts_slider_content_type !== 'page' ) : ?>
                            <span class="cat-links">
                                <?php the_category( '', '', $content['id'] ); ?>
                            </span><!-- .cat-links -->
                        <?php endif; ?>
                        <?php power_news_pro_posted_on( $content['id'] ); ?>
                    </div><!-- .entry-meta -->

                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                    </header>
                    <?php echo power_news_pro_author( $content['auth_id'] ); ?>
                </div><!-- .entry-container -->
            </article>
    <?php endforeach; ?>
    </div><!-- .featured-slider -->
</div><!-- #power_news_pro_posts_slider_section -->
<?php endif; ?>

