<?php
/**
 * Product Collection Section
 *
 * This is the template for the content of product collection section
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */
if ( ! function_exists( 'power_news_pro_add_products_collection_section' ) ) :
    /**
    * Add product collection section
    *
    *@since Power News Pro 1.0.0
    */
    function power_news_pro_add_products_collection_section() {
        $options = power_news_pro_get_theme_options();
        // Check if product collection is enabled on frontpage
        $products_collection_enable = apply_filters( 'power_news_pro_section_status', true, 'products_collection_section_enable' );

        if ( ( true !== $products_collection_enable) || ! class_exists( 'WooCommerce' ) ) {
            return false;
        }

        // Render product collection section now.
        power_news_pro_render_products_collection_section();
    }
endif;

if ( ! function_exists( 'power_news_pro_render_products_collection_section' ) ) :
  /**
   * Start product collection section
   *
   * @return string product collection content
   * @since Power News Pro 1.0.0
   *
   */
   function power_news_pro_render_products_collection_section() {
        $options = power_news_pro_get_theme_options();

    ?>

    <div id="power_news_pro_products_collection_section" class="featured-products-section relative page-section same-background">
        <div class="wrapper">
            <?php if ( is_customize_preview()):
                power_news_pro_section_tooltip( 'featured-products-section-class' );
            endif; ?>
            <div class="section-header">
              <?php if( !empty( $options['products_collection_subtitle'] ) ): ?>
                <p class="section-subtitle"><?php echo esc_html( $options['products_collection_subtitle'] ); ?></p>
            <?php endif;
            if( !empty( $options['products_collection_title'] ) ):
                ?>
                <h2 class="section-title"><?php echo esc_html( $options['products_collection_title'] ); ?></h2>
            <?php endif; ?>
            </div><!-- .section-header -->

            <div class="section-content grid clear col-2">

                <?php for ( $i=1; $i <= $options['products_collection_count']; $i++ ) { 
                    if ( empty($options['products_collection_content_product_category_'.$i]) ) {
                        continue;
                    }
                    $thumbnail_id = get_term_meta( $options['products_collection_content_product_category_'.$i], 'thumbnail_id', true );
                    $image        = wp_get_attachment_url( $thumbnail_id );
                    $cat_name     = get_term_by( 'id', $options['products_collection_content_product_category_'.$i], 'product_cat' )->name;
                    $banner_title = empty( $options['products_collection_banner_title_'.$i] ) ? '' : $options['products_collection_banner_title_'.$i];

                    $banner_description = empty( $options['products_collection_banner_description_'.$i] ) ? '' : $options['products_collection_banner_description_'.$i];

                    $banner_btn = empty( $options['products_collection_button_'.$i] ) ? '' : $options['products_collection_button_'.$i];
                    $cat_link   = get_category_link( $options['products_collection_content_product_category_'.$i] );
                    ?>

                    <article class="grid-item">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                            <div class="entry-container">
                                <span class="cat-links">
                                    <ul class="post-categories">
                                        <li><a href="<?php echo esc_url( $cat_link ); ?>"><?php echo esc_html( $cat_name ); ?></a></li>
                                    </ul>
                                </span><!-- .cat-links -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $cat_link ); ?>"><?php echo esc_html( $banner_title ); ?></a></h2>
                                </header>

                                <?php if( !empty( $banner_btn ) ): ?>

                                    <div class="read-more">
                                        <a href="<?php echo esc_url( $cat_link ); ?>" class="btn"><?php echo esc_html( $banner_btn ); ?></a>
                                    </div><!-- .read-more -->

                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </div><!-- .featured-image -->
                    </article>

                    <?php } ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>

    <?php }
endif;