<?php
/**
* Promotion Section
*
* This is the template for the content of promotion section
*
* @package Theme Palace
* @subpackage Power News Pro
* @since Power News Pro 1.0.0
*/
if ( ! function_exists( 'power_news_pro_add_promotion_section' ) ) :

function power_news_pro_add_promotion_section(){

$options = power_news_pro_get_theme_options();

if($options['promotion_section_enable'] !== false ):

        // Content type.
    $promotion_content_type  = $options['promotion_content_type'];

    $content_details = array();
    switch ( $promotion_content_type ) {

        case 'custom':
        $custom['title']        = ! empty( $options['promotion_title'] ) ? $options['promotion_title'] : '';
        $custom['excerpt']      = ! empty( $options['promotion_description'] ) ? $options['promotion_description'] : '';
        $custom['image']        = ! empty( $options['promotion_image'] ) ? $options['promotion_image'] : get_template_directory_uri() . '/assets/uploads/call-to-action.jpg';
        $custom['url']          = ! empty( $options['promotion_btn_link'] ) ? $options['promotion_btn_link'] : '';

        // Push to the main array.
        array_push( $content_details, $custom );
        break;

        case 'page':
        $page_id = ! empty( $options['promotion_content_page'] ) ? $options['promotion_content_page'] : '';
        $args = array(
            'post_type'         => 'page',
            'page_id'           => $page_id,
            'posts_per_page'    => 1,
        );                    
        break;

        case 'post':
        $post_id = ! empty( $options['promotion_content_post'] ) ? $options['promotion_content_post'] : '';
        $args = array(
            'post_type'         => 'post',
            'p'                 => $post_id,
            'posts_per_page'    => 1,
        );
        break;

        default:
        break;
    }

    if ( 'custom' !== $promotion_content_type ) :
            // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = power_news_pro_trim_content( 25 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/call-to-action.jpg';

                    // Push to the main array.
                array_push( $content_details, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();
    endif;
    ?>

    <?php foreach ( $content_details as $content ) :
        $url = ( $options['promotion_content_type'] == 'custom' ) ? $options['promotion_btn_link'] : $content['url'];
        $readmore = ! empty( $options['promotion_btn_title'] ) ? $options['promotion_btn_title'] : esc_html__( 'Read More', 'power-news-pro' );
        ?>
        <div id="power_news_pro_promotion_section" class="promotion-section relative page-section" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <?php if ( is_customize_preview()):
                    power_news_pro_section_tooltip( 'promotion-section-class' );
                endif; ?>
                <header class="entry-header">
                    <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                </header>

                <div class="entry-content">
                    <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                </div><!-- .entry-content -->
                <?php if( !empty( $url ) && !empty( $options['promotion_btn_title'] ) ): ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $url ); ?>" class="btn"><?php echo esc_html( $readmore ); ?></a>
                    </div><!-- .read-more -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #promotion-section -->
    <?php endforeach; ?>
<?php endif;
}
endif;
?>

