<?php
/**
 * Subscription section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage Power News Pro
 * @since Power News Pro 1.0.0
 */
if ( ! function_exists( 'power_news_pro_add_subscribe_us_section' ) ) :
    /**
    * Add subscription section
    *
    *@since Power News Pro 1.0.0
    */
    function power_news_pro_add_subscribe_us_section() {
        $options = power_news_pro_get_theme_options();

        // Check if subscription is enabled on frontpage
        $subscribe_us_enable = apply_filters( 'power_news_pro_section_status', true, 'subscribe_us_section_enable' );

        if ( true !== $subscribe_us_enable ) {
           return false;
        }

        // Render subscription section now.
        power_news_pro_render_subscribe_us_section();
    }
endif;

if ( ! function_exists( 'power_news_pro_render_subscribe_us_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since Power News Pro 1.0.0
   *
   */
   function power_news_pro_render_subscribe_us_section() {
        if ( ! class_exists( 'Jetpack' ) ) {
           return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
               return;
        }
        $options = power_news_pro_get_theme_options();

        $subscribe_us_btn_title         = ! empty( $options['subscribe_us_btn_title'] ) ? $options['subscribe_us_btn_title'] : esc_html__( 'Subscribe Now', 'power-news-pro' );
        $subscribe_us_title             = ! empty( $options['subscribe_us_title'] ) ? $options['subscribe_us_title'] : '';
        $subscribe_us_description       = ! empty( $options['subscribe_us_description'] ) ? $options['subscribe_us_description'] : '';
        $subscribe_us_sub_title         = ! empty( $options['subscribe_us_sub_title'] ) ? $options['subscribe_us_sub_title'] : esc_html__( 'Subscribe Now', 'power-news-pro' );
        $subscribe_us_bg_image          = ! empty( $options['subscribe_us_bg_image'] ) ? $options['subscribe_us_bg_image'] : '#';
        
        ?>
        <div id="power_news_pro_subscribe_us_section" class="subscribe-us-section page-section same-background">
          <?php if ( is_customize_preview()):
            power_news_pro_section_tooltip( 'subscribe-us-section-class' );
          endif; ?>
          <div class="wrapper">
            <article class="has-post-thumbnail">
             <div class="featured-image" style="background-image: url('<?php echo esc_url($subscribe_us_bg_image); ?>');">
             </div><!-- .featured-image -->
             <div class="entry-container">
              <div class="section-header">
                <?php if ( ! empty( $options['subscribe_us_sub_title'] ) ) : ?>
                  <p class="section-subtitle"><?php echo esc_html( $options['subscribe_us_sub_title'] ); ?></p>
                <?php endif; ?>
                <?php if ( ! empty( $options['subscribe_us_title'] ) ) : ?>
                  <h2 class="section-title"><?php echo esc_html( $subscribe_us_title ); ?></h2>
                <?php endif; ?>
              </div><!-- .section-header-wrapper -->

              <div class="entry-content">
                <?php echo esc_html( $subscribe_us_description); ?> 
                <?php 
                $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_text="" subscribe_button="' . esc_html( $subscribe_us_btn_title ) . '" show_subscribers_total="0"]';
                echo do_shortcode( wp_kses_post( $subscription_shortcode ) ); 
                ?>
              </div><!-- .entry-content -->
            </div><!-- .entry-container -->
          </article>
        </div><!-- .wrapper -->
      </div>

    <?php }
endif;


